Type: Package
Package: overviewR
Title: Easily Extracting Information About Your Data
Version: 0.0.14
Authors@R: c(
    person("Cosima", "Meyer", , "cosima.meyer@gmail.com", role = c("cre", "aut")),
    person("Dennis", "Hammerschmidt", , "dennis_hammerschmidt@yahoo.com", role = "aut")
  )
Description: Makes it easy to display descriptive information on a data
    set.  Getting an easy overview of a data set by displaying and
    visualizing sample information in different tables (e.g., time and
    scope conditions).  The package also provides publishable 'LaTeX' code
    to present the sample information.
License: GPL-3
URL: https://github.com/cosimameyer/overviewR
BugReports: https://github.com/cosimameyer/overviewR/issues
Depends: R (>= 3.5.0)
Imports: data.table (>= 1.14.2), dplyr (>= 1.0.0), ggplot2 (>= 3.3.2),
        ggrepel (>= 0.8.2), ggvenn (>= 0.1.8), rlang, tibble (>=
        3.0.1), tidyr
Suggests: countrycode, covr, devtools, eulerr, knitr, magrittr,
        pkgdown, rmarkdown, spelling, testthat, xtable
VignetteBuilder: knitr, rmarkdown
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-05-05 06:32:21 UTC; cosima
Author: Cosima Meyer [cre, aut],
  Dennis Hammerschmidt [aut]
Maintainer: Cosima Meyer <cosima.meyer@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-05 06:50:02 UTC
Built: R 4.6.0; ; 2026-05-05 07:09:00 UTC; unix

Type: Package
Package: overviewR
Title: Easily Extracting Information About Your Data
Version: 0.0.14
Authors@R: c(
    person("Cosima", "Meyer", , "cosima.meyer@gmail.com", role = c("cre", "aut")),
    person("Dennis", "Hammerschmidt", , "dennis_hammerschmidt@yahoo.com", role = "aut")
  )
Description: Makes it easy to display descriptive information on a data
    set.  Getting an easy overview of a data set by displaying and
    visualizing sample information in different tables (e.g., time and
    scope conditions).  The package also provides publishable 'LaTeX' code
    to present the sample information.
License: GPL-3
URL: https://github.com/cosimameyer/overviewR
BugReports: https://github.com/cosimameyer/overviewR/issues
Depends: R (>= 3.5.0)
Imports: data.table (>= 1.14.2), dplyr (>= 1.0.0), ggplot2 (>= 3.3.2),
        ggrepel (>= 0.8.2), ggvenn (>= 0.1.8), rlang, tibble (>=
        3.0.1), tidyr
Suggests: countrycode, covr, devtools, eulerr, knitr, magrittr,
        pkgdown, rmarkdown, spelling, testthat, xtable
VignetteBuilder: knitr, rmarkdown
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2026-05-05 06:32:21 UTC; cosima
Author: Cosima Meyer [cre, aut],
  Dennis Hammerschmidt [aut]
Maintainer: Cosima Meyer <cosima.meyer@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-05 06:50:02 UTC
Built: R 4.6.0; ; 2026-05-05 08:35:02 UTC; unix

# Generated by roxygen2: do not edit by hand

export(overview_crossplot)
export(overview_crosstab)
export(overview_heat)
export(overview_latex)
export(overview_markdown)
export(overview_na)
export(overview_overlap)
export(overview_plot)
export(overview_tab)
importFrom(data.table,data.table)
importFrom(dplyr,"%>%")
importFrom(ggplot2,ggplot)
importFrom(ggrepel,geom_text_repel)
importFrom(ggvenn,ggvenn)
importFrom(rlang,":=")
importFrom(rlang,enexpr)
importFrom(stats,reorder)
importFrom(tibble,"rownames_to_column")

# overviewR <img src='man/figures/logo.png' align="right" height="139" />

<!-- badges: start -->

[![tests](https://github.com/cosimameyer/overviewR/workflows/tests/badge.svg)](https://github.com/cosimameyer/overviewR/actions)
[![Codecov test
coverage](https://codecov.io/gh/cosimameyer/overviewR/branch/main/graph/badge.svg)](https://app.codecov.io/gh/cosimameyer/overviewR?branch=main)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/overviewR)](https://cran.r-project.org/package=overviewR)
[![license](https://img.shields.io/badge/license-GPL--3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![metacran downloads](https://cranlogs.r-pkg.org/badges/overviewR)](https://cran.r-project.org/package=overviewR)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![overviewR badge](https://img.shields.io/badge/overviewR-ready%20to%20use-brightgreen)](https://github.com/cosimameyer/overviewR)
[![R badge](https://img.shields.io/badge/Build%20with-♥%20and%20R-blue)](https://github.com/cosimameyer/overviewR)
[![DOI](https://joss.theoj.org/papers/10.21105/joss.04740/status.svg)](https://doi.org/10.21105/joss.04740)
[![cran checks](https://badges.cranchecks.info/worst/overviewR.svg)](https://cran.r-project.org/web/checks/check_results_overviewR.html)

<!--<a href="https://diffify.com/R/overviewR" target="_blank"><img src="https://img.shields.io/static/v1?label=&amp;message=Diffify&amp;labelColor=black&amp;color=black&amp;style=flat-square&amp;logo=data:image/svg+xml;base64, " alt="The Diffify page for the R package overviewR" style="width: 100px; max-width: 100%;"></a>-->
<!-- [![Rdoc](https://www.rdocumentation.org/badges/version/overviewR)](https://www.rdocumentation.org/packages/overviewR) -->
<!-- [![](https://cranlogs.r-pkg.org/badges/version/overviewR)](https://www.r-pkg.org/badges/version/overviewR) -->
<!-- [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) -->
<!-- [![Last-changedate](https://img.shields.io/badge/last%20change-2022--09--12-green.svg)](/commits/master) -->
<!-- badges: end -->

[**You can access the CheatSheet for overviewR
here**](https://github.com/cosimameyer/overviewR/blob/master/man/figures/CheatSheet_overviewR.pdf)

The goal of overviewR is to make it easy to get an overview of a data
set by displaying relevant sample information. At the moment, there are
the following functions:

-   `overview_tab` generates a tabular overview of the sample. The
    general sample plots a two-column table that provides information on
    an id in the left column and a the time frame on the right column.
-   `overview_crosstab` generates a cross table. The conditional column
    allows to disaggregate the overview table by specifying two
    conditions, hence resulting a 2x2 table. This way, it is easy to
    visualize the time and scope conditions as well as theoretical
    assumptions with examples from the data set.
-   `overview_latex` converts the output of both `overview_tab` and
    `overview_crosstab` into LaTeX code and/or directly into a .tex
    file.
-   `overview_plot` is an alternative to visualize the sample (a way to
    present results from `overview_tab`)
-   `overview_crossplot` is an alternative to visualize a cross table (a
    way to present results from `overview_crosstab`)
-   `overview_heat` plots a heat map of your time line
-   `overview_na` plots an overview of missing values by variable (both
    by row and by column)
-   `overview_overlap` plots comparison plots (bar graph and Venn
    diagram) to compare to data frames

The plots can be saved using the `ggsave()` command. The output of
`overview_tab` and `overview_crosstab` are also compatible with other
packages such as [`xtable`](https://CRAN.R-project.org/package=xtable),
[`flextable`](https://CRAN.R-project.org/package=flextable), or
[`knitr`](https://yihui.org/rmarkdown-cookbook/kable.html).

We present a short step-by-step guide as well as the functions in more
detail below.

## Installation

A stable version of `overviewR` can be directly accessed on CRAN:

```{r, eval = FALSE}
install.packages("overviewR", force = TRUE)
```

To install the latest development version of `overviewR` directly from
[GitHub](https://github.com/cosimameyer/overviewR) use:

``` r
library(devtools) # Tools to Make Developing R Packages Easier # Tools to Make Developing R Packages Easier
devtools::install_github("cosimameyer/overviewR")
```

## Example

First, load the package.

``` r
library(overviewR) # Easily Extracting Information About Your Data # Easily Extracting Information About Your Data
```

The following examples use a toy data set (`toydata`) that comes with
the package. This data contains artificially generated information in a
cross-sectional format on 5 countries, covering the period 1990-1999.

``` r
data(toydata)
head(toydata)
#>   ccode year month      gdp population day
#> 1   RWA 1990   Jan 24180.77  14969.988   1
#> 2   RWA 1990   Jan 23650.53  11791.464   2
#> 3   RWA 1990   Jan 21860.14  30047.979   3
#> 4   RWA 1990   Jan 20801.06  19853.556   4
#> 5   RWA 1990   Jan 18702.84   5148.118   5
#> 6   RWA 1990   Jan 30272.37  48625.140   6
```

<!-- ``` -->
<!--     ccode   year   month  gdp       population -->
<!--     RWA     1990   Jan    24180.77  14969.988 -->
<!--     RWA     1990   Feb    23650.53  11791.464 -->
<!--     RWA     1990   Mar    21860.14  30047.979 -->
<!--     RWA     1990   Apr    20801.06  19853.556 -->
<!--     RWA     1990   May    18702.84   5148.118 -->
<!--     RWA     1990   Jun    30272.37  48625.140 -->
<!-- ``` -->

There are 264 observations for 5 countries (Angola, Benin, France,
Rwanda, and UK) stored in the `ccode` variable, over a time period
between 1990 to 1999 (`year`) with additional information for the month
(`month`). Additionally, two artificially generated fake variables for
GDP (`gdp`) and population size (`population`) are included to
illustrate of conditions.

The following functions work best on data sets that have an
id-time-structure, in the case of `toydata` this corresponds to
country-year with `ccode` and `year`. If the data set does not have this
format yet, consider using [`pivot_wider()` or
`pivot_longer()`](https://tidyr.tidyverse.org/reference/pivot_longer.html)
to get to the format.

### `overview_tab`

Generate some general overview of the data set using the time and scope
conditions with `overview_tab`.

``` r
output_table <- overview_tab(dat = toydata, id = ccode, time = year)
```

The resulting data frame collapses the time condition for each id by
taking into account potential gaps in the time frame. Note that the
column name for the time frame is set by default to `time_frame` and
internally generated when using `overview_tab`.

``` r
output_table
```

    # ccode   time_frame
    # RWA       1990 - 1995
    # AGO       1990 - 1992
    # BEN       1995 - 1999
    # GBR       1991, 1993, 1995, 1997, 1999
    # FRA       1993, 1996, 1999

### Multiple time arguments

As of overviewR version 0.0.7 you can also use multiple time objects in
`overview_tab`. You can now pass a list containing multiple time
variables with the following format:
`time = list(year = NULL, month = NULL, day = NULL)`.

``` r
output_table_complex <- overview_tab(dat = toydata, id = ccode, time = list(year = toydata$year,
             month = toydata$month, day = toydata$day), complex_date = TRUE)
```

The resulting data frame collapses again the time condition for each id
by taking into account potential gaps in the time frame. Note that the
column name for the time frame is set by default to `time_frame` and
internally generated when using `overview_tab`. The output resembles
something like this:

``` r
output_table_complex
```

     ccode time_frame                                                                                                      # AGO   1990-01-01, 1990-02-02, 1990-03-03, 1990-04-04, 1990-05-05, 1990-06-06, ...
    # BEN   1995-01-01, 1995-02-02, 1995-03-03, 1995-04-04, 1995-05-05, 1995-06-06, ...
    # FRA   1993-01-01, 1993-02-02, 1993-03-03, 1993-04-04, 1993-05-05, 1993-06-06, ...
    # GBR   1991-01-01, 1991-02-02, 1991-03-03, 1991-04-04, 1991-05-05, 1991-06-06, ...
    # RWA   1990-01-01 - 1990-01-12, 1991-01-01 - 1991-01-12, 1992-01-01 - 1992-01-12, 1993-01-01 - 1993-01-12, 1994-01-01 

### `overview_crosstab`

To generate a cross table that divides the data based on two conditions,
for instance GDP and population size, `overview_crosstab` can be used.
`threshold1` and `threshold2` thereby indicate the cut point for the two
conditions (`cond1` and `cond2`), respectively.

``` r
output_crosstab <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
```

The data frame output looks as follows:

    #   part1                                      part2
    # 1 AGO (1990, 1992), FRA (1993), GBR (1997)   BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)
    # 2 BEN (1997), RWA (1990)                     AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)

Note, if a data set is used that has multiple observations on the
id-time unit, the function automatically aggregates the data set using
the mean of condition 1 (`cond1`) and condition 2 (`cond2`).

### `overview_latex`

> With overviewR v 0.0.11.999 we introduced `overview_latex` instead of
> `overview_print`

To generate an easily usable LaTeX output for the generated
`overview_tab` and `overview_crosstab` objects, `overviewR` offers the
function `overview_latex`. The following illustrate this using the
`output_table` object from `overview_tab`.

``` r
overview_latex(obj = output_table)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    \begin{table}[ht] 
     \centering 
     \caption{Time and scope of the sample} 
     \begin{tabular}{ll} 
     \hline 
    Sample & Time frame \\ 
    \hline 
     RWA & 1990 - 1995 \\ 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     \hline 
     \end{tabular} 
     \end{table}

</details>
<p align="center">
<img src='man/figures/ex1.png' height="150"/>
</p>

The default already provides a title (“Time and scope of the sample”)
that can be modified in the argument `title`. The same holds for the
column names (“Sample” and “Time frame” are set by default but can be
modified as shown below).

``` r
overview_latex(
  obj = output_table,
  id = "Countries",
  time = "Years",
  title = "Cool new title for our awesome table"
)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    \begin{table}[ht] 
     \centering 
     \caption{Cool new title for our awesome table} 
     \begin{tabular}{ll} 
     \hline 
    Countries & Years \\ 
    \hline 
     RWA & 1990 - 1995 \\ 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     \hline 
     \end{tabular} 
     \end{table} 

</details>
<p align="center">
<img src='man/figures/ex2.png' height="150"/>
</p>

The same function can also be used for outputs from the
`overview_crosstab` function by using the argument `crosstab = TRUE`.
There are also options to label the respective conditions (`cond1` and
`cond2`). Note that this should correspond to the conditions (`cond1`
and `cond2`) specified in the `overview_crosstab` function.

``` r
overview_latex(
  obj = output_crosstab,
  title = "Cross table of the sample",
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    % Please add the following packages to your document preamble: 
    % \usepackage{multirow} 
    % \usepackage{tabularx} 
    % \newcolumntype{b}{X} 
    % \newcolumntype{s}{>{\hsize=.5\hsize}X} 
    \begin{table}[ht] 
    \caption{Cross table of the sample} 
     \begin{tabularx}{\textwidth}{ssbb} 
    \hline & & \multicolumn{2}{c}{\textbf{GDP}} \\ 
     & & \textbf{Fulfilled} & \textbf{Not fulfilled} \\ 
     \hline \\ 
     \multirow{2}{*}{\textbf{Population}} & \textbf{Fulfilled} & 
     AGO (1990, 1992), FRA (1993), GBR (1997) & BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)\\  
     \\ \hline \\ 
     & \textbf{Not fulfilled} &  BEN (1997), RWA (1990) & AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)\\  \hline \\ 
     \end{tabularx} 
     \end{table} 

</details>
<p align="center">
<img src='man/figures/ex3.png' height="200"/>
</p>

`overview_latex` further allows more specifications such as the font
size or a a label. *These functions are currently supported only in the
development version of the package.*

``` r
overview_latex(obj = output_table,
               fontsize = "scriptsize",
               label = "tab:overview")
```

With `save_out = TRUE` the function exports the output as a `.tex` file
and stores it on the device.

``` r
overview_latex(
  obj = output_table,
  save_out = TRUE,
  file_path = "SET-YOUR-PATH/output.tex"
)
```

### `overview_plot`

In addition to tables, `overviewR` also provides plots to illustrate the
structure of your data. `overview_plot` illustrates the information that
is generated in `overview_table` in a ggplot graphic. All scope objects
(e.g., countries) are listed on the y-axis where horizontal lines
indicate the coverage across the entire time frame of the data (x-axis).
This helps to spot gaps in the data for specific scope objects and
outlines at what time point they occur.

``` r
data(toydata)
overview_plot(dat = toydata, id = ccode, time = year)
```

<img src="man/figures/unnamed-chunk-22-1.png" width="50%" style="display: block; margin: auto;" />

The results are sorted alphabetically by default. The order can also be
reversed by setting `asc` to `FALSE`.

``` r
library(magrittr) # A Forward-Pipe Operator for R

overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  asc = FALSE
)
```

<img src="man/figures/unnamed-chunk-23-1.png" width="50%" style="display: block; margin: auto;" />

There is also an option to color the time lines conditionally. Here, we
introduce a dummy variable that indicates whether the year was before
1995 or not. We use this dummy to color the time lines using the `color`
argument.

``` r
# Code whether a year was before 1995
toydata <- toydata %>%
  dplyr::mutate(before = ifelse(year < 1995, 1, 0))

# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
)
```

<img src=”man/figures/unnamed-chunk-24-1.png” width=”50%” style=”display: block; margin: auto;” />

Since `overview_plot` returns a ggplot object, you can apply any ggplot2
color scale directly by adding a layer. This works for any number of
categories.

``` r
library(ggplot2)

# Explicit colors via scale_color_manual
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_manual(values = c(“#E84646”, “#4E84C4”))
```

``` r
# RColorBrewer palette via scale_color_brewer
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_brewer(palette = “Set1”)
```

The development version also allows to change the dot size using the
`dot_size` argument. The default is “2”.

``` r
# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  dot_size = 5
)
```

<p align="center">
<img src='man/figures/dot.png' height="400"/>
</p>

### `overview_crossplot`

To visualize also the cross table, `overview_crossplot` does the job.

``` r
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE,
  label = TRUE
)
```

<img src="man/figures/unnamed-chunk-26-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_heat`

`overview_heat` takes a closer look at the time and scope conditions by
visualizing the data coverage for each time and scope combination in a
ggplot heat map. This function is best explained using an example.
Suppose you have a dataset with monthly data for different countries and
want to know if data is available for each country in every month.
`overview_heat` intuitively does this by plotting a heat map where each
cell indicates the coverage for that specific combination of time and
scope (e,g., country-year). As illustrated below, the darker the cell
is, the more coverage it has. The plot also indicates the relative or
absolute coverage of each cell. For instance, Angola (“AGO”) in 1991
shows the coverage of 75%. This means that of all potential 12 months of
coverage (12 months for one year), only 9 are covered.

For this purpose, we first artificially reduced the `toydata`.

``` r
toydata_red <- toydata[-sample(seq_len(nrow(toydata)), 64),]
```

``` r
overview_heat(toydata_red,
              ccode,
              year,
              perc = TRUE,
              exp_total = 12)
```

<img src="man/figures/unnamed-chunk-28-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_na`

`overview_na` is a simple function that provides information about the
content of all variables in your data, not only the time and scope
conditions. It returns a horizontal ggplot bar plot that indicates the
amount of missing data (NAs) for each variable (on the y-axis). You can
choose whether to display the relative amount of NAs for each variable
in percentage (the default) or the total number of NAs.

For this purpose, we first artificially reduced our `toydata`.

``` r
toydata_with_na <- toydata %>%
  dplyr::mutate(
    year = ifelse(year < 1992, NA, year),
    month = ifelse(month %in% c("Jan", "Jun", "Aug"), NA, month),
    gdp = ifelse(gdp < 20000, NA, gdp)
  )
```

``` r
overview_na(toydata_with_na)
```

<img src="man/figures/unnamed-chunk-30-1.png" width="50%" style="display: block; margin: auto;" />

``` r
overview_na(toydata_with_na, perc = FALSE)
```

<img src="man/figures/unnamed-chunk-31-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_overlap`

This function allows to compare two data sets. We are currently working
on an extended version that allows comparing \>2 data sets.

At the current development stage, the function works as follows:

``` r
library(dplyr)

# Subset one data set for comparison
toydata2 <- toydata %>% dplyr::filter(year > 1992)

overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "bar" # This is the default
)
#> Joining, by = "ccode"
#> Warning: Removed 1 rows containing missing values (geom_bar).
```

<img src="man/figures/unnamed-chunk-32-1.png" width="50%" style="display: block; margin: auto;" />

<!--<p align="center">
<img src='man/figures/bar.png' height="400"/>
</p>-->

Or a Venn diagram

``` r
overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "venn"
)
```

<img src="man/figures/unnamed-chunk-33-1.png" width="50%" style="display: block; margin: auto;" />

<!--<p align="center">
<img src='man/figures/venn.png' height="400"/>
</p>
-->

## Compatibilities with other packages

### Presenting tables: `flextable`, `xtable`, and `kable`

The outputs of `overview_tab` and `overview_crosstab` are also
compatible with other functions such as
[`xtable`](https://CRAN.R-project.org/package=xtable),
[`flextable`](https://CRAN.R-project.org/package=flextable), or
[`kable`](https://yihui.org/rmarkdown-cookbook/kable.html) from
[`knitr`](https://yihui.org/knitr/).

Two examples are shown below:

``` r
library(flextable) # not installed on this machine
table_output <- qflextable(output_table)
table_output <-
  set_header_labels(table_output,
                    ccode = "Countries",
                    time_frame = "Time frame")
set_table_properties(table_output,
                     width = .4,
                     layout = "autofit")
```

``` r
library(knitr) # A General-Purpose Package for Dynamic Report Generation in R
knitr::kable(output_table)
```

| ccode | time_frame                   |
|:------|:-----------------------------|
| RWA   | 1990-1995                    |
| AGO   | 1990-1992                    |
| BEN   | 1995-1999                    |
| GBR   | 1991, 1993, 1995, 1997, 1999 |
| FRA   | 1993, 1996, 1999             |

### Customizing plots: `ggplot2` and other packages

The plot functions are fully `ggplot2` based. While a theme is
pre-defined, this can easily be overwritten.

A classical `ggplot2` theme alternative

``` r
library(ggplot2) # Create Elegant Data Visualisations Using the Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal() 
```

<img src="man/figures/unnamed-chunk-37-1.png" width="50%" style="display: block; margin: auto;" />

### Workflow: `tidyverse`

All functions are further easily accessible using a common `tidyverse`
workflow. Here are just three examples – the possibilities are endless.

Using a filter function

``` r
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata_with_na %>%
  dplyr::filter(year > 1993) %>%
  overview_na()
```

<img src="man/figures/unnamed-chunk-38-1.png" width="50%" style="display: block; margin: auto;" />

Using mutate to generate meaningful country names

```{r, eval = FALSE}
library(countrycode) # Convert Country Names and Country Codes
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata %>%
  # Transform the country code (ISO3 character code) into a country name using the `countrycode` package
  dplyr::mutate(country = countrycode::countrycode(ccode, "iso3c", "country.name")) %>%
  overview_plot(id = country, time = year)
```

<img src="man/figures/unnamed-chunk-39-1.png" width="50%" style="display: block; margin: auto;" />

Using different `overviewR` functions after each other to generate a
workflow

``` r
# Produces a printable LaTeX output
toydata %>%
  overview_tab(id = ccode, time = year) %>%
  overview_latex()
```

    % Overview table generated in R version 4.0.2 (2020-06-22) using overviewR 
    % Table created on 2020-12-30
    \begin{table}[ht] 
     \centering 
     \caption{Time and scope of the sample} 
    \label{tab:tab1} 

    \begin{tabular}{ll} 
     \hline 
    Sample & Time frame \\ 
    \hline 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     RWA & 1990 - 1995 \\ 
     \hline 
     \end{tabular} 
     \end{table} 

## Overview of functional add-ons

|                      | Works with `data.frame` objects | Works with `data.table` | Can take multiple time arguments (year, month, day) |
|----------------------|---------------------------------|-------------------------|-----------------------------------------------------|
| `overview_tab`       | ✓                               | ✓                       | ✓                                                   |
| `overview_na`        | ✓                               | ✓                       |                                                     |
| `overview_plot`      | ✓                               |                         |                                                     |
| `overview_crossplot` | ✓                               |                         |                                                     |
| `overview_crosstab`  | ✓                               |                         |                                                     |
| `overview_heat`      | ✓                               |                         |                                                     |
| `overview_overlap`   | ✓                               |                         |                                                     |

## Extensions

If you wish to compare two data sets using `overview_tab`, this is not
(yet) implemented in `overviewR` but there is currently a workaround.

``` r
library(overviewR)
library(dplyr)
library(xtable)

# Load data
data(toydata)

# Restrict the data so that we have something to compare :-)
toydata_res <- toydata %>%
  dplyr::filter(year > 1992)

# Generate two overview_tab objects
dat1 <- overview_tab(toydata, id = ccode, time = year)
dat2 <- overview_tab(toydata_res, id = ccode, time = year)

# And now we use full_join to combine both
dat_full <- dat1 %>%
  dplyr::full_join(dat2, by = "ccode") %>%
  dplyr::rename(time_dat1 = time_frame.x,
                time_dat2 = time_frame.y)
```

Having a look at the output, we see that this is exactly what we wanted
to have:

``` r
head(dat_full)
```

    #> # A tibble: 5 x 3
    #> # Groups:   ccode [5]
    #>   ccode time_dat1                    time_dat2             
    #>   <chr> <chr>                        <chr>                 
    #> 1 AGO   1990 - 1992                  <NA>                  
    #> 2 BEN   1995 - 1999                  1995 - 1999           
    #> 3 FRA   1993, 1996, 1999             1993, 1996, 1999      
    #> 4 GBR   1991, 1993, 1995, 1997, 1999 1993, 1995, 1997, 1999
    #> 5 RWA   1990 - 1995                  1993 - 1995

`overview_latex` cannot handle this object (yet), so we use `xtable`
instead which gives us the LaTeX output.

``` r
print(xtable(dat_full), include.rownames = FALSE)
```

    % latex table generated in R 4.0.2 by xtable 1.8-4 package
    % Tue Feb 16 18:20:51 2021
    \begin{table}[ht]
    \centering
    \begin{tabular}{lll}
      \hline
    ccode & time\_dat1 & time\_dat2 \\ 
      \hline
    AGO & 1990 - 1992 &  \\ 
      BEN & 1995 - 1999 & 1995 - 1999 \\ 
      FRA & 1993, 1996, 1999 & 1993, 1996, 1999 \\ 
      GBR & 1991, 1993, 1995, 1997, 1999 & 1993, 1995, 1997, 1999 \\ 
      RWA & 1990 - 1995 & 1993 - 1995 \\ 
       \hline
    \end{tabular}
    \end{table}

</details>
<p align="center">
<img src='man/figures/extension1.png' height="150"/>
</p>

# What’s unique about overviewR?

With a specific focus on time-series cross-sectional data, it is unique
in its coverage. The details are outlined in the table below:

| Key functionalities                                                               | overviewR (0.0.11) | DataExplorer (0.8.2) | dlookR (0.6.0) | gtsummary (1.6.1) | Hmisc (4.7-1) | naniar (0.6.1) | skimr (2.1.4) | smartEDA (0.3.8) | summarytools (1.0.1) |
|-----------------------------------------------------------------------------------|--------------------|----------------------|----------------|-------------------|---------------|----------------|---------------|------------------|----------------------|
| Shows time-series cross-sectional data coverage                                   | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Allows to quickly report time-series cross-sectional data coverage (figure/table) | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows NAs                                                                         | ✓                  | ✓                    | ✓              | ✓                 | ✓             | ✓              | ✓             | ✓                | ✓                    |
| Shows NAs (in a figure)                                                           | ✓                  | ✓                    | ✓              |                   |               | ✓              |               |                  |                      |
| Shows overlap between two data frames (based on time and id)                      | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows cross-table                                                                 | ✓                  |                      |                | ✓                 |               |                |               | ✓                | ✓                    |
| Shows cross-table based on country-year units                                     | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows cross-tables (in a figure)                                                  | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Reports descriptive statistics                                                    |                    | ✓                    | ✓              | ✓                 | ✓             | ✓              | ✓             | ✓                | ✓                    |
| Shows value type                                                                  |                    | ✓                    | ✓              | ✓                 |               | ✓              | ✓             | ✓                | ✓                    |

# How to reach out?

### Where do I report bugs?

Simply [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) on GitHub.

### How do I contribute to the package?

If you have an idea (but no code yet), [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) on GitHub.
If you want to contribute with a specific feature and have the code
ready, fork the repository, add your code, and create a pull request.

### Do you need support?

The easiest way is to [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) - this way,
your question is also visible to others who may face similar problems.

# Credits

The hex sticker is generated by ourselves using the
[`hexSticker`](https://github.com/GuangchuangYu/hexSticker) package.

# overviewR <img src='man/figures/logo.png' align="right" height="139" />

<!-- badges: start -->

[![tests](https://github.com/cosimameyer/overviewR/workflows/tests/badge.svg)](https://github.com/cosimameyer/overviewR/actions)
[![Codecov test
coverage](https://codecov.io/gh/cosimameyer/overviewR/branch/main/graph/badge.svg)](https://app.codecov.io/gh/cosimameyer/overviewR?branch=main)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/overviewR)](https://cran.r-project.org/package=overviewR)
[![license](https://img.shields.io/badge/license-GPL--3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![metacran downloads](https://cranlogs.r-pkg.org/badges/overviewR)](https://cran.r-project.org/package=overviewR)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![overviewR badge](https://img.shields.io/badge/overviewR-ready%20to%20use-brightgreen)](https://github.com/cosimameyer/overviewR)
[![R badge](https://img.shields.io/badge/Build%20with-♥%20and%20R-blue)](https://github.com/cosimameyer/overviewR)
[![DOI](https://joss.theoj.org/papers/10.21105/joss.04740/status.svg)](https://doi.org/10.21105/joss.04740)
[![cran checks](https://badges.cranchecks.info/worst/overviewR.svg)](https://cran.r-project.org/web/checks/check_results_overviewR.html)

<!--<a href="https://diffify.com/R/overviewR" target="_blank"><img src="https://img.shields.io/static/v1?label=&amp;message=Diffify&amp;labelColor=black&amp;color=black&amp;style=flat-square&amp;logo=data:image/svg+xml;base64,[encoded data, 5288 characters]" alt="The Diffify page for the R package overviewR" style="width: 100px; max-width: 100%;"></a>-->
<!-- [![Rdoc](https://www.rdocumentation.org/badges/version/overviewR)](https://www.rdocumentation.org/packages/overviewR) -->
<!-- [![](https://cranlogs.r-pkg.org/badges/version/overviewR)](https://www.r-pkg.org/badges/version/overviewR) -->
<!-- [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) -->
<!-- [![Last-changedate](https://img.shields.io/badge/last%20change-2022--09--12-green.svg)](/commits/master) -->
<!-- badges: end -->

[**You can access the CheatSheet for overviewR
here**](https://github.com/cosimameyer/overviewR/blob/master/man/figures/CheatSheet_overviewR.pdf)

The goal of overviewR is to make it easy to get an overview of a data
set by displaying relevant sample information. At the moment, there are
the following functions:

-   `overview_tab` generates a tabular overview of the sample. The
    general sample plots a two-column table that provides information on
    an id in the left column and a the time frame on the right column.
-   `overview_crosstab` generates a cross table. The conditional column
    allows to disaggregate the overview table by specifying two
    conditions, hence resulting a 2x2 table. This way, it is easy to
    visualize the time and scope conditions as well as theoretical
    assumptions with examples from the data set.
-   `overview_latex` converts the output of both `overview_tab` and
    `overview_crosstab` into LaTeX code and/or directly into a .tex
    file.
-   `overview_plot` is an alternative to visualize the sample (a way to
    present results from `overview_tab`)
-   `overview_crossplot` is an alternative to visualize a cross table (a
    way to present results from `overview_crosstab`)
-   `overview_heat` plots a heat map of your time line
-   `overview_na` plots an overview of missing values by variable (both
    by row and by column)
-   `overview_overlap` plots comparison plots (bar graph and Venn
    diagram) to compare to data frames

The plots can be saved using the `ggsave()` command. The output of
`overview_tab` and `overview_crosstab` are also compatible with other
packages such as [`xtable`](https://CRAN.R-project.org/package=xtable),
[`flextable`](https://CRAN.R-project.org/package=flextable), or
[`knitr`](https://yihui.org/rmarkdown-cookbook/kable.html).

We present a short step-by-step guide as well as the functions in more
detail below.

## Installation

A stable version of `overviewR` can be directly accessed on CRAN:

```{r, eval = FALSE}
install.packages("overviewR", force = TRUE)
```

To install the latest development version of `overviewR` directly from
[GitHub](https://github.com/cosimameyer/overviewR) use:

``` r
library(devtools) # Tools to Make Developing R Packages Easier # Tools to Make Developing R Packages Easier
devtools::install_github("cosimameyer/overviewR")
```

## Example

First, load the package.

``` r
library(overviewR) # Easily Extracting Information About Your Data # Easily Extracting Information About Your Data
```

The following examples use a toy data set (`toydata`) that comes with
the package. This data contains artificially generated information in a
cross-sectional format on 5 countries, covering the period 1990-1999.

``` r
data(toydata)
head(toydata)
#>   ccode year month      gdp population day
#> 1   RWA 1990   Jan 24180.77  14969.988   1
#> 2   RWA 1990   Jan 23650.53  11791.464   2
#> 3   RWA 1990   Jan 21860.14  30047.979   3
#> 4   RWA 1990   Jan 20801.06  19853.556   4
#> 5   RWA 1990   Jan 18702.84   5148.118   5
#> 6   RWA 1990   Jan 30272.37  48625.140   6
```

<!-- ``` -->
<!--     ccode   year   month  gdp       population -->
<!--     RWA     1990   Jan    24180.77  14969.988 -->
<!--     RWA     1990   Feb    23650.53  11791.464 -->
<!--     RWA     1990   Mar    21860.14  30047.979 -->
<!--     RWA     1990   Apr    20801.06  19853.556 -->
<!--     RWA     1990   May    18702.84   5148.118 -->
<!--     RWA     1990   Jun    30272.37  48625.140 -->
<!-- ``` -->

There are 264 observations for 5 countries (Angola, Benin, France,
Rwanda, and UK) stored in the `ccode` variable, over a time period
between 1990 to 1999 (`year`) with additional information for the month
(`month`). Additionally, two artificially generated fake variables for
GDP (`gdp`) and population size (`population`) are included to
illustrate of conditions.

The following functions work best on data sets that have an
id-time-structure, in the case of `toydata` this corresponds to
country-year with `ccode` and `year`. If the data set does not have this
format yet, consider using [`pivot_wider()` or
`pivot_longer()`](https://tidyr.tidyverse.org/reference/pivot_longer.html)
to get to the format.

### `overview_tab`

Generate some general overview of the data set using the time and scope
conditions with `overview_tab`.

``` r
output_table <- overview_tab(dat = toydata, id = ccode, time = year)
```

The resulting data frame collapses the time condition for each id by
taking into account potential gaps in the time frame. Note that the
column name for the time frame is set by default to `time_frame` and
internally generated when using `overview_tab`.

``` r
output_table
```

    # ccode   time_frame
    # RWA       1990 - 1995
    # AGO       1990 - 1992
    # BEN       1995 - 1999
    # GBR       1991, 1993, 1995, 1997, 1999
    # FRA       1993, 1996, 1999

### Multiple time arguments

As of overviewR version 0.0.7 you can also use multiple time objects in
`overview_tab`. You can now pass a list containing multiple time
variables with the following format:
`time = list(year = NULL, month = NULL, day = NULL)`.

``` r
output_table_complex <- overview_tab(dat = toydata, id = ccode, time = list(year = toydata$year,
             month = toydata$month, day = toydata$day), complex_date = TRUE)
```

The resulting data frame collapses again the time condition for each id
by taking into account potential gaps in the time frame. Note that the
column name for the time frame is set by default to `time_frame` and
internally generated when using `overview_tab`. The output resembles
something like this:

``` r
output_table_complex
```

     ccode time_frame                                                                                                      # AGO   1990-01-01, 1990-02-02, 1990-03-03, 1990-04-04, 1990-05-05, 1990-06-06, ...
    # BEN   1995-01-01, 1995-02-02, 1995-03-03, 1995-04-04, 1995-05-05, 1995-06-06, ...
    # FRA   1993-01-01, 1993-02-02, 1993-03-03, 1993-04-04, 1993-05-05, 1993-06-06, ...
    # GBR   1991-01-01, 1991-02-02, 1991-03-03, 1991-04-04, 1991-05-05, 1991-06-06, ...
    # RWA   1990-01-01 - 1990-01-12, 1991-01-01 - 1991-01-12, 1992-01-01 - 1992-01-12, 1993-01-01 - 1993-01-12, 1994-01-01 

### `overview_crosstab`

To generate a cross table that divides the data based on two conditions,
for instance GDP and population size, `overview_crosstab` can be used.
`threshold1` and `threshold2` thereby indicate the cut point for the two
conditions (`cond1` and `cond2`), respectively.

``` r
output_crosstab <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
```

The data frame output looks as follows:

    #   part1                                      part2
    # 1 AGO (1990, 1992), FRA (1993), GBR (1997)   BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)
    # 2 BEN (1997), RWA (1990)                     AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)

Note, if a data set is used that has multiple observations on the
id-time unit, the function automatically aggregates the data set using
the mean of condition 1 (`cond1`) and condition 2 (`cond2`).

### `overview_latex`

> With overviewR v 0.0.11.999 we introduced `overview_latex` instead of
> `overview_print`

To generate an easily usable LaTeX output for the generated
`overview_tab` and `overview_crosstab` objects, `overviewR` offers the
function `overview_latex`. The following illustrate this using the
`output_table` object from `overview_tab`.

``` r
overview_latex(obj = output_table)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    \begin{table}[ht] 
     \centering 
     \caption{Time and scope of the sample} 
     \begin{tabular}{ll} 
     \hline 
    Sample & Time frame \\ 
    \hline 
     RWA & 1990 - 1995 \\ 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     \hline 
     \end{tabular} 
     \end{table}

</details>
<p align="center">
<img src='man/figures/ex1.png' height="150"/>
</p>

The default already provides a title (“Time and scope of the sample”)
that can be modified in the argument `title`. The same holds for the
column names (“Sample” and “Time frame” are set by default but can be
modified as shown below).

``` r
overview_latex(
  obj = output_table,
  id = "Countries",
  time = "Years",
  title = "Cool new title for our awesome table"
)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    \begin{table}[ht] 
     \centering 
     \caption{Cool new title for our awesome table} 
     \begin{tabular}{ll} 
     \hline 
    Countries & Years \\ 
    \hline 
     RWA & 1990 - 1995 \\ 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     \hline 
     \end{tabular} 
     \end{table} 

</details>
<p align="center">
<img src='man/figures/ex2.png' height="150"/>
</p>

The same function can also be used for outputs from the
`overview_crosstab` function by using the argument `crosstab = TRUE`.
There are also options to label the respective conditions (`cond1` and
`cond2`). Note that this should correspond to the conditions (`cond1`
and `cond2`) specified in the `overview_crosstab` function.

``` r
overview_latex(
  obj = output_crosstab,
  title = "Cross table of the sample",
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
```

<details>
<summary>
LaTeX output
</summary>

    % Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
    % Table created on 2020-06-21
    % Please add the following packages to your document preamble: 
    % \usepackage{multirow} 
    % \usepackage{tabularx} 
    % \newcolumntype{b}{X} 
    % \newcolumntype{s}{>{\hsize=.5\hsize}X} 
    \begin{table}[ht] 
    \caption{Cross table of the sample} 
     \begin{tabularx}{\textwidth}{ssbb} 
    \hline & & \multicolumn{2}{c}{\textbf{GDP}} \\ 
     & & \textbf{Fulfilled} & \textbf{Not fulfilled} \\ 
     \hline \\ 
     \multirow{2}{*}{\textbf{Population}} & \textbf{Fulfilled} & 
     AGO (1990, 1992), FRA (1993), GBR (1997) & BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)\\  
     \\ \hline \\ 
     & \textbf{Not fulfilled} &  BEN (1997), RWA (1990) & AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)\\  \hline \\ 
     \end{tabularx} 
     \end{table} 

</details>
<p align="center">
<img src='man/figures/ex3.png' height="200"/>
</p>

`overview_latex` further allows more specifications such as the font
size or a a label. *These functions are currently supported only in the
development version of the package.*

``` r
overview_latex(obj = output_table,
               fontsize = "scriptsize",
               label = "tab:overview")
```

With `save_out = TRUE` the function exports the output as a `.tex` file
and stores it on the device.

``` r
overview_latex(
  obj = output_table,
  save_out = TRUE,
  file_path = "SET-YOUR-PATH/output.tex"
)
```

### `overview_plot`

In addition to tables, `overviewR` also provides plots to illustrate the
structure of your data. `overview_plot` illustrates the information that
is generated in `overview_table` in a ggplot graphic. All scope objects
(e.g., countries) are listed on the y-axis where horizontal lines
indicate the coverage across the entire time frame of the data (x-axis).
This helps to spot gaps in the data for specific scope objects and
outlines at what time point they occur.

``` r
data(toydata)
overview_plot(dat = toydata, id = ccode, time = year)
```

<img src="man/figures/unnamed-chunk-22-1.png" width="50%" style="display: block; margin: auto;" />

The results are sorted alphabetically by default. The order can also be
reversed by setting `asc` to `FALSE`.

``` r
library(magrittr) # A Forward-Pipe Operator for R

overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  asc = FALSE
)
```

<img src="man/figures/unnamed-chunk-23-1.png" width="50%" style="display: block; margin: auto;" />

There is also an option to color the time lines conditionally. Here, we
introduce a dummy variable that indicates whether the year was before
1995 or not. We use this dummy to color the time lines using the `color`
argument.

``` r
# Code whether a year was before 1995
toydata <- toydata %>%
  dplyr::mutate(before = ifelse(year < 1995, 1, 0))

# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
)
```

<img src=”man/figures/unnamed-chunk-24-1.png” width=”50%” style=”display: block; margin: auto;” />

Since `overview_plot` returns a ggplot object, you can apply any ggplot2
color scale directly by adding a layer. This works for any number of
categories.

``` r
library(ggplot2)

# Explicit colors via scale_color_manual
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_manual(values = c(“#E84646”, “#4E84C4”))
```

``` r
# RColorBrewer palette via scale_color_brewer
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_brewer(palette = “Set1”)
```

The development version also allows to change the dot size using the
`dot_size` argument. The default is “2”.

``` r
# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  dot_size = 5
)
```

<p align="center">
<img src='man/figures/dot.png' height="400"/>
</p>

### `overview_crossplot`

To visualize also the cross table, `overview_crossplot` does the job.

``` r
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE,
  label = TRUE
)
```

<img src="man/figures/unnamed-chunk-26-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_heat`

`overview_heat` takes a closer look at the time and scope conditions by
visualizing the data coverage for each time and scope combination in a
ggplot heat map. This function is best explained using an example.
Suppose you have a dataset with monthly data for different countries and
want to know if data is available for each country in every month.
`overview_heat` intuitively does this by plotting a heat map where each
cell indicates the coverage for that specific combination of time and
scope (e,g., country-year). As illustrated below, the darker the cell
is, the more coverage it has. The plot also indicates the relative or
absolute coverage of each cell. For instance, Angola (“AGO”) in 1991
shows the coverage of 75%. This means that of all potential 12 months of
coverage (12 months for one year), only 9 are covered.

For this purpose, we first artificially reduced the `toydata`.

``` r
toydata_red <- toydata[-sample(seq_len(nrow(toydata)), 64),]
```

``` r
overview_heat(toydata_red,
              ccode,
              year,
              perc = TRUE,
              exp_total = 12)
```

<img src="man/figures/unnamed-chunk-28-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_na`

`overview_na` is a simple function that provides information about the
content of all variables in your data, not only the time and scope
conditions. It returns a horizontal ggplot bar plot that indicates the
amount of missing data (NAs) for each variable (on the y-axis). You can
choose whether to display the relative amount of NAs for each variable
in percentage (the default) or the total number of NAs.

For this purpose, we first artificially reduced our `toydata`.

``` r
toydata_with_na <- toydata %>%
  dplyr::mutate(
    year = ifelse(year < 1992, NA, year),
    month = ifelse(month %in% c("Jan", "Jun", "Aug"), NA, month),
    gdp = ifelse(gdp < 20000, NA, gdp)
  )
```

``` r
overview_na(toydata_with_na)
```

<img src="man/figures/unnamed-chunk-30-1.png" width="50%" style="display: block; margin: auto;" />

``` r
overview_na(toydata_with_na, perc = FALSE)
```

<img src="man/figures/unnamed-chunk-31-1.png" width="50%" style="display: block; margin: auto;" />

### `overview_overlap`

This function allows to compare two data sets. We are currently working
on an extended version that allows comparing \>2 data sets.

At the current development stage, the function works as follows:

``` r
library(dplyr)

# Subset one data set for comparison
toydata2 <- toydata %>% dplyr::filter(year > 1992)

overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "bar" # This is the default
)
#> Joining, by = "ccode"
#> Warning: Removed 1 rows containing missing values (geom_bar).
```

<img src="man/figures/unnamed-chunk-32-1.png" width="50%" style="display: block; margin: auto;" />

<!--<p align="center">
<img src='man/figures/bar.png' height="400"/>
</p>-->

Or a Venn diagram

``` r
overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "venn"
)
```

<img src="man/figures/unnamed-chunk-33-1.png" width="50%" style="display: block; margin: auto;" />

<!--<p align="center">
<img src='man/figures/venn.png' height="400"/>
</p>
-->

## Compatibilities with other packages

### Presenting tables: `flextable`, `xtable`, and `kable`

The outputs of `overview_tab` and `overview_crosstab` are also
compatible with other functions such as
[`xtable`](https://CRAN.R-project.org/package=xtable),
[`flextable`](https://CRAN.R-project.org/package=flextable), or
[`kable`](https://yihui.org/rmarkdown-cookbook/kable.html) from
[`knitr`](https://yihui.org/knitr/).

Two examples are shown below:

``` r
library(flextable) # not installed on this machine
table_output <- qflextable(output_table)
table_output <-
  set_header_labels(table_output,
                    ccode = "Countries",
                    time_frame = "Time frame")
set_table_properties(table_output,
                     width = .4,
                     layout = "autofit")
```

``` r
library(knitr) # A General-Purpose Package for Dynamic Report Generation in R
knitr::kable(output_table)
```

| ccode | time_frame                   |
|:------|:-----------------------------|
| RWA   | 1990-1995                    |
| AGO   | 1990-1992                    |
| BEN   | 1995-1999                    |
| GBR   | 1991, 1993, 1995, 1997, 1999 |
| FRA   | 1993, 1996, 1999             |

### Customizing plots: `ggplot2` and other packages

The plot functions are fully `ggplot2` based. While a theme is
pre-defined, this can easily be overwritten.

A classical `ggplot2` theme alternative

``` r
library(ggplot2) # Create Elegant Data Visualisations Using the Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal() 
```

<img src="man/figures/unnamed-chunk-37-1.png" width="50%" style="display: block; margin: auto;" />

### Workflow: `tidyverse`

All functions are further easily accessible using a common `tidyverse`
workflow. Here are just three examples – the possibilities are endless.

Using a filter function

``` r
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata_with_na %>%
  dplyr::filter(year > 1993) %>%
  overview_na()
```

<img src="man/figures/unnamed-chunk-38-1.png" width="50%" style="display: block; margin: auto;" />

Using mutate to generate meaningful country names

```{r, eval = FALSE}
library(countrycode) # Convert Country Names and Country Codes
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata %>%
  # Transform the country code (ISO3 character code) into a country name using the `countrycode` package
  dplyr::mutate(country = countrycode::countrycode(ccode, "iso3c", "country.name")) %>%
  overview_plot(id = country, time = year)
```

<img src="man/figures/unnamed-chunk-39-1.png" width="50%" style="display: block; margin: auto;" />

Using different `overviewR` functions after each other to generate a
workflow

``` r
# Produces a printable LaTeX output
toydata %>%
  overview_tab(id = ccode, time = year) %>%
  overview_latex()
```

    % Overview table generated in R version 4.0.2 (2020-06-22) using overviewR 
    % Table created on 2020-12-30
    \begin{table}[ht] 
     \centering 
     \caption{Time and scope of the sample} 
    \label{tab:tab1} 

    \begin{tabular}{ll} 
     \hline 
    Sample & Time frame \\ 
    \hline 
     AGO & 1990 - 1992 \\ 
     BEN & 1995 - 1999 \\ 
     FRA & 1993, 1996, 1999 \\ 
     GBR & 1991, 1993, 1995, 1997, 1999 \\ 
     RWA & 1990 - 1995 \\ 
     \hline 
     \end{tabular} 
     \end{table} 

## Overview of functional add-ons

|                      | Works with `data.frame` objects | Works with `data.table` | Can take multiple time arguments (year, month, day) |
|----------------------|---------------------------------|-------------------------|-----------------------------------------------------|
| `overview_tab`       | ✓                               | ✓                       | ✓                                                   |
| `overview_na`        | ✓                               | ✓                       |                                                     |
| `overview_plot`      | ✓                               |                         |                                                     |
| `overview_crossplot` | ✓                               |                         |                                                     |
| `overview_crosstab`  | ✓                               |                         |                                                     |
| `overview_heat`      | ✓                               |                         |                                                     |
| `overview_overlap`   | ✓                               |                         |                                                     |

## Extensions

If you wish to compare two data sets using `overview_tab`, this is not
(yet) implemented in `overviewR` but there is currently a workaround.

``` r
library(overviewR)
library(dplyr)
library(xtable)

# Load data
data(toydata)

# Restrict the data so that we have something to compare :-)
toydata_res <- toydata %>%
  dplyr::filter(year > 1992)

# Generate two overview_tab objects
dat1 <- overview_tab(toydata, id = ccode, time = year)
dat2 <- overview_tab(toydata_res, id = ccode, time = year)

# And now we use full_join to combine both
dat_full <- dat1 %>%
  dplyr::full_join(dat2, by = "ccode") %>%
  dplyr::rename(time_dat1 = time_frame.x,
                time_dat2 = time_frame.y)
```

Having a look at the output, we see that this is exactly what we wanted
to have:

``` r
head(dat_full)
```

    #> # A tibble: 5 x 3
    #> # Groups:   ccode [5]
    #>   ccode time_dat1                    time_dat2             
    #>   <chr> <chr>                        <chr>                 
    #> 1 AGO   1990 - 1992                  <NA>                  
    #> 2 BEN   1995 - 1999                  1995 - 1999           
    #> 3 FRA   1993, 1996, 1999             1993, 1996, 1999      
    #> 4 GBR   1991, 1993, 1995, 1997, 1999 1993, 1995, 1997, 1999
    #> 5 RWA   1990 - 1995                  1993 - 1995

`overview_latex` cannot handle this object (yet), so we use `xtable`
instead which gives us the LaTeX output.

``` r
print(xtable(dat_full), include.rownames = FALSE)
```

    % latex table generated in R 4.0.2 by xtable 1.8-4 package
    % Tue Feb 16 18:20:51 2021
    \begin{table}[ht]
    \centering
    \begin{tabular}{lll}
      \hline
    ccode & time\_dat1 & time\_dat2 \\ 
      \hline
    AGO & 1990 - 1992 &  \\ 
      BEN & 1995 - 1999 & 1995 - 1999 \\ 
      FRA & 1993, 1996, 1999 & 1993, 1996, 1999 \\ 
      GBR & 1991, 1993, 1995, 1997, 1999 & 1993, 1995, 1997, 1999 \\ 
      RWA & 1990 - 1995 & 1993 - 1995 \\ 
       \hline
    \end{tabular}
    \end{table}

</details>
<p align="center">
<img src='man/figures/extension1.png' height="150"/>
</p>

# What’s unique about overviewR?

With a specific focus on time-series cross-sectional data, it is unique
in its coverage. The details are outlined in the table below:

| Key functionalities                                                               | overviewR (0.0.11) | DataExplorer (0.8.2) | dlookR (0.6.0) | gtsummary (1.6.1) | Hmisc (4.7-1) | naniar (0.6.1) | skimr (2.1.4) | smartEDA (0.3.8) | summarytools (1.0.1) |
|-----------------------------------------------------------------------------------|--------------------|----------------------|----------------|-------------------|---------------|----------------|---------------|------------------|----------------------|
| Shows time-series cross-sectional data coverage                                   | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Allows to quickly report time-series cross-sectional data coverage (figure/table) | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows NAs                                                                         | ✓                  | ✓                    | ✓              | ✓                 | ✓             | ✓              | ✓             | ✓                | ✓                    |
| Shows NAs (in a figure)                                                           | ✓                  | ✓                    | ✓              |                   |               | ✓              |               |                  |                      |
| Shows overlap between two data frames (based on time and id)                      | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows cross-table                                                                 | ✓                  |                      |                | ✓                 |               |                |               | ✓                | ✓                    |
| Shows cross-table based on country-year units                                     | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Shows cross-tables (in a figure)                                                  | ✓                  |                      |                |                   |               |                |               |                  |                      |
| Reports descriptive statistics                                                    |                    | ✓                    | ✓              | ✓                 | ✓             | ✓              | ✓             | ✓                | ✓                    |
| Shows value type                                                                  |                    | ✓                    | ✓              | ✓                 |               | ✓              | ✓             | ✓                | ✓                    |

# How to reach out?

### Where do I report bugs?

Simply [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) on GitHub.

### How do I contribute to the package?

If you have an idea (but no code yet), [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) on GitHub.
If you want to contribute with a specific feature and have the code
ready, fork the repository, add your code, and create a pull request.

### Do you need support?

The easiest way is to [open an
issue](https://github.com/cosimameyer/overviewR/issues/new) - this way,
your question is also visible to others who may face similar problems.

# Credits

The hex sticker is generated by ourselves using the
[`hexSticker`](https://github.com/GuangchuangYu/hexSticker) package.

## ----eval=FALSE---------------------------------------------------------------
# install.packages("overviewR", force = TRUE)

## ----message=FALSE, warning=FALSE, results = "hide", eval=FALSE---------------
# library(devtools)
# devtools::install_github("cosimameyer/overviewR")

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE,
                      comment = "#>")
options(repos = c(CRAN = "[https://cloud.r-project.org](https://cloud.r-project.org)"))

## ----echo=FALSE,results='hide',message=FALSE,include=FALSE, eval=TRUE---------
if (!require(knitr))
  install.packages("knitr")
if (!require(devtools))
  install.packages("devtools")
if (!require(dplyr))
  install.packages("dplyr")
if (!require(magrittr))
  install.packages("magrittr")
if (!require(ggplot2))
  install.packages("ggplot2")
if (!require(countrycode))
  install.packages("countrycode")
if (!require(xtable))
  install.packages("xtable")

## ----eval=FALSE---------------------------------------------------------------
# install.packages("overviewR", force = TRUE)

## ----message=FALSE, warning=FALSE, results = "hide", eval=FALSE---------------
# library(devtools)
# devtools::install_github("cosimameyer/overviewR")

## ----include = FALSE, eval = FALSE--------------------------------------------
# install.packages("overviewR")

## ----message=FALSE, warning=FALSE---------------------------------------------
library(overviewR)

## -----------------------------------------------------------------------------
data(toydata)
head(toydata)

## ----message=FALSE, warning=FALSE, eval=FALSE---------------------------------
# output_table <- overview_tab(dat = toydata, id = ccode, time = year)

## ----message=FALSE, eval=FALSE------------------------------------------------
# output_table

## ----message=FALSE, eval=FALSE------------------------------------------------
# output_table_complex <- overview_tab(dat = toydata, id = ccode,
#                                      time = list(year = toydata$year,
#                                                  month = toydata$month,
#                                                  day = toydata$day),
#                                      complex_date = TRUE)

## ----message=FALSE, eval=FALSE------------------------------------------------
# output_table_complex

## ----message=FALSE, warning=FALSE, eval=FALSE---------------------------------
# output_crosstab <- overview_crosstab(
#   dat = toydata,
#   cond1 = gdp,
#   cond2 = population,
#   threshold1 = 25000,
#   threshold2 = 27000,
#   id = ccode,
#   time = year
# )

## ----message=FALSE, echo=FALSE, eval=FALSE------------------------------------
# output_crosstab

## ----eval=FALSE---------------------------------------------------------------
# overview_latex(obj = output_table)

## ----eval=FALSE, include=FALSE------------------------------------------------
# overview_latex(obj = output_table)

## ----eval = FALSE, eval=FALSE-------------------------------------------------
# overview_latex(
#   obj = output_table,
#   id = "Countries",
#   time = "Years",
#   title = "Cool new title for our awesome table"
# )

## ----eval=FALSE, include=FALSE------------------------------------------------
# overview_latex(
#   obj = output_table,
#   id = "Countries",
#   time = "Years",
#   title = "Cool new title for our awesome table"
# )

## ----eval = FALSE-------------------------------------------------------------
# overview_latex(
#   obj = output_crosstab,
#   title = "Cross table of the sample",
#   crosstab = TRUE,
#   cond1 = "GDP",
#   cond2 = "Population"
# )

## ----eval=FALSE, include=FALSE------------------------------------------------
# overview_latex(
#   obj = output_crosstab,
#   title = "Cross table of the sample",
#   crosstab = TRUE,
#   cond1 = "GDP",
#   cond2 = "Population"
# )

## ----eval = FALSE-------------------------------------------------------------
# overview_latex(obj = output_table,
#                fontsize = "scriptsize",
#                label = "tab:overview")

## ----eval = FALSE-------------------------------------------------------------
# overview_latex(
#   obj = output_table,
#   save_out = TRUE,
#   file_path = "SET-YOUR-PATH/output.tex"
# )

## ----eval=FALSE---------------------------------------------------------------
# overview_markdown(obj = output_table)

## ----eval=FALSE---------------------------------------------------------------
# overview_markdown(
#   obj = output_table,
#   id = "Countries",
#   time = "Years",
#   title = "My custom title"
# )

## ----eval=FALSE---------------------------------------------------------------
# overview_markdown(
#   obj = output_crosstab,
#   crosstab = TRUE,
#   cond1 = "GDP",
#   cond2 = "Population"
# )

## ----eval=FALSE---------------------------------------------------------------
# overview_markdown(
#   obj = output_table,
#   save_out = TRUE,
#   file_path = "output/overview.md"
# )

## ----out.width = '50%', fig.align='center'------------------------------------
data(toydata)
overview_plot(dat = toydata, id = ccode, time = year)

## ----out.width = '50%', fig.align='center'------------------------------------
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  asc = FALSE
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
library(overviewR) # Easily Extracting Information About Your Data
library(magrittr) # A Forward-Pipe Operator for R

# Code whether a year was before 1995
toydata <- toydata %>%
  dplyr::mutate(before = ifelse(year < 1995, 1, 0))

# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
library(ggplot2)

# Explicit colors via scale_color_manual
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_manual(values = c("#E84646", "#4E84C4"))

## ----eval = FALSE-------------------------------------------------------------
# # RColorBrewer palette via scale_color_brewer
# overview_plot(
#   dat = toydata,
#   id = ccode,
#   time = year,
#   color = before
# ) +
#   ggplot2::scale_color_brewer(palette = "Set1")

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
# Plot using the `dot_size` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  dot_size = 5
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  label = TRUE
)

## ----out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE----
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE,
  label = TRUE
)

## ----include = TRUE-----------------------------------------------------------
toydata_red <- toydata[-sample(seq_len(nrow(toydata)), 64), ]

## ----out.width = '50%', fig.align='center'------------------------------------
overview_heat(toydata_red,
              ccode,
              year,
              perc = TRUE,
              exp_total = 12)

## ----include=TRUE-------------------------------------------------------------
toydata_with_na <- toydata %>%
  dplyr::mutate(
    year = ifelse(year < 1992, NA, year),
    month = ifelse(month %in% c("Jan", "Jun", "Aug"), NA, month),
    gdp = ifelse(gdp < 20000, NA, gdp)
  )

## ----out.width = '50%', fig.align='center'------------------------------------
overview_na(toydata_with_na)

## ----out.width = '50%', fig.align='center'------------------------------------
overview_na(toydata_with_na, perc = FALSE)

## ----out.width = '50%', fig.align='center'------------------------------------
overview_na(toydata_with_na, row_wise = TRUE)

## ----out.width = '50%', fig.align='center'------------------------------------
overview_na(toydata_with_na, row_wise = TRUE, perc = FALSE)

## ----eval=FALSE---------------------------------------------------------------
# toydata_extended <- overview_na(toydata_with_na, row_wise = TRUE, add = TRUE)
# head(toydata_extended)

## ----out.width = '50%', fig.align='center', eval = TRUE-----------------------
library(dplyr)

# Subset one data set for comparison
toydata2 <- toydata %>% dplyr::filter(year > 1992)

overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "bar" # This is the default
)

## ----out.width = '50%', fig.align='center'------------------------------------
library(ggplot2) # Create Elegant Data Visualisations 
                 # Using the Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal()

## ----out.width = '50%', fig.align='center'------------------------------------
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata_with_na %>%
  dplyr::filter(year > 1993) %>%
  overview_na()

## ----out.width = '50%', fig.align='center'------------------------------------
library(countrycode) # Convert Country Names and Country Codes
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata %>%
  # Transform the country code (ISO3 character code) into a country name using
  # the `countrycode` package
  dplyr::mutate(country =
                  countrycode::countrycode(ccode, "iso3c", "country.name")) %>%
  overview_plot(id = country, time = year)

## ----eval = FALSE-------------------------------------------------------------
# # Produces a printable LaTeX output
# toydata %>%
#   overview_tab(id = ccode, time = year) %>%
#   overview_latex()

## ----eval=FALSE---------------------------------------------------------------
# library(flextable) # not installed on this machine
# table_output <- qflextable(output_table)
# table_output <-
#   set_header_labels(table_output,
#                     ccode = "Countries",
#                     time_frame = "Time frame")
# set_table_properties(table_output,
#                      width = .4,
#                      layout = "autofit")

## ----echo=FALSE, include=FALSE------------------------------------------------
output_table <-
  data.frame(
    ccode = c("RWA", "AGO", "BEN", "GBR", "FRA"),
    time_frame = c(
      "1990-1995",
      "1990-1992",
      "1995-1999",
      "1991, 1993, 1995, 1997, 1999",
      "1993, 1996, 1999"
    )
  )

## -----------------------------------------------------------------------------
library(knitr) # A General-Purpose Package for Dynamic Report Generation in R
knitr::kable(output_table)

## ----out.width = '50%', fig.align='center'------------------------------------
library(ggplot2) # Create Elegant Data Visualisations Using the
# Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal()

## ----eval=TRUE----------------------------------------------------------------
library(overviewR)
library(dplyr)
library(xtable)

# Load data
data(toydata)

# Restrict the data so that we have something to compare :-)
toydata_res <- toydata %>%
  dplyr::filter(year > 1992)

# Generate two overview_tab objects
dat1 <- overview_tab(toydata, id = ccode, time = year)
dat2 <- overview_tab(toydata_res, id = ccode, time = year)

# And now we use full_join to combine both
dat_full <- dat1 %>%
  dplyr::full_join(dat2, by = "ccode") %>%
  dplyr::rename(time_dat1 = time_frame.x,
                time_dat2 = time_frame.y)

## ----eval=FALSE---------------------------------------------------------------
# head(dat_full)

## ----eval=FALSE---------------------------------------------------------------
# print(xtable(dat_full), include.rownames = FALSE)

#' @title theme_na_plot
#'
#' @description Defines the theme for the `overview_na` plot function
#'
#' @return A theme for the `overview_na` plot
#'
theme_na_plot <- function() {
  plot_theme <- ggplot2::theme(
    # get rid of panel grids
    axis.line = ggplot2::element_blank(),
    axis.ticks.y = ggplot2::element_blank(),
    axis.ticks.x = ggplot2::element_blank(),
    panel.border = ggplot2::element_blank(),
    panel.grid.major = ggplot2::element_blank(),
    panel.grid.minor = ggplot2::element_blank(),
    # Change plot and panel background
    plot.background = ggplot2::element_rect(fill = "white"),
    panel.background = ggplot2::element_rect(fill = "white"),
    # Change legend
    legend.direction = "horizontal",
    legend.background = ggplot2::element_rect(fill = "black", color = NA),
    legend.key = ggplot2::element_rect(color = "black", fill = "black"),
    legend.title = ggplot2::element_blank(),
    # Change text
    plot.caption = ggplot2::element_text(size = 5),
    axis.text = ggplot2::element_text(
      face = "plain",
      color = "black",
      size = 8
    ),
    text = ggplot2::element_text(
      size = 10,
      face = "plain"
    )
  )

  return(plot_theme)
}

#' @title overview_overlap
#'
#' @description Provides an overview of the overlap of two data sets.
#'     Cautionary note: This function is currently only preliminary workable
#'     and can only capture 2 data sets. We are working on an extension that
#'     allows to compare multiple data sets.
#'
#' @param dat1 A first data set object
#' @param dat2 A second data set object
#' @param dat1_id Scope (e.g., country codes or individual IDs) of dat1.
#'     It is important that both ID variables are exactly the same to generate
#'     the perfect match.
#' @param dat2_id Scope (e.g., country codes or individual IDs) of dat2.
#'     It is important that both ID variables are exactly the same to generate
#'     the perfect match.
#' @param dat1_name Name of dat1 ("Data set 1" is the default)
#' @param dat2_name Name of dat2 ("Data set 2" is the default)
#' @param plot_type Type of plot ("bar" and "venn" are the two options) "venn"
#'     relies on the ggvenn function
#' @param proportional Logical. If \code{TRUE} and \code{plot_type = "venn"},
#'     draws a proportional Euler diagram using the \pkg{eulerr} package
#'     (must be installed separately). The returned object is an
#'     \code{eulergram} (base-R graphics), not a ggplot2 object.
#'     Default is \code{FALSE}.
#' @return A ggplot2 object (bar chart or standard Venn diagram), or an
#'     \code{eulergram} object when \code{proportional = TRUE}.
#' @examples
#' \dontrun{
#' data(toydata)
#' toydata2 <- toydata[which(toydata$year > 1992), ]
#' overview_overlap(
#'   dat1 = toydata, dat2 = toydata2, dat1_id = ccode,
#'   dat2_id = ccode
#' )
#' }
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom ggplot2 ggplot
#' @importFrom ggvenn ggvenn

overview_overlap <-
  function(dat1,
           dat2,
           dat1_id,
           dat2_id,
           dat1_name = "Data set 1",
           dat2_name = "Data set 2",
           plot_type = "bar",
           proportional = FALSE) {
    dat1 <- dat1
    dat2 <- dat2
    dat1_id <- dplyr::enquo(dat1_id)
    dat2_id <- dplyr::enquo(dat2_id)

    if (plot_type == "bar") {
      dat1_final <- dat1 %>%
        # Subset it to the ID
        dplyr::select(!!dat1_id) %>%
        # Group by ID
        dplyr::group_by(!!dat1_id) %>%
        # Count occurences of each ID
        dplyr::count() %>%
        # Rename the count variable
        dplyr::rename(count = n)

      dat2_final <- dat2 %>%
        # Subset it to the ID
        dplyr::select(!!dat2_id) %>%
        # Group by ID
        dplyr::group_by(!!dat2_id) %>%
        # Count occurences of each ID
        dplyr::count() %>%
        # Rename the count variable
        dplyr::rename(count2 = n)

      # Merge both data sets to get a better idea of the overlap
      subset <-
        # Join both data sets
        dplyr::full_join(x = dat1_final, y = dat2_final)

      # Plot it
      plot <- subset %>%
        tidyr::pivot_longer(count:count2, names_to = "count") %>%
        dplyr::group_by(!!dat1_id) %>%
        ggplot2::ggplot(ggplot2::aes(
          x = !!dat1_id,
          y = value,
          fill = count
        )) +
        ggplot2::geom_bar(
          stat = "identity",
          width = .5,
          position = "dodge"
        ) +
        ggplot2::scale_fill_grey(
          name = "Data set",
          breaks = c("count", "count2"),
          labels = c(dat1_name, dat2_name)
        ) +
        ggplot2::theme_classic() +
        ggplot2::xlab("Identifier") +
        ggplot2::ylab("Count (absolute number of observations)") +
        ggplot2::ggtitle("Overlap of data sets")

      # Return plot
      return(plot)
    }
    if (plot_type == "venn") {
      # Subset the id to a vector
      dat1_sub <- dplyr::select(dat1, !!dat1_id) %>%
        unlist() %>%
        as.vector()
      dat2_sub <- dplyr::select(dat2, !!dat2_id) %>%
        unlist() %>%
        as.vector()

      if (proportional) {
        if (!requireNamespace("eulerr", quietly = TRUE)) {
          stop(
            "Package 'eulerr' is required for proportional Venn diagrams. ",
            "Install it with: install.packages('eulerr')"
          )
        }
        n1 <- length(unique(dat1_sub))
        n2 <- length(unique(dat2_sub))
        n_both <- length(intersect(unique(dat1_sub), unique(dat2_sub)))
        combo <- c(n1 - n_both, n2 - n_both, n_both)
        names(combo) <- c(dat1_name, dat2_name,
                          paste0(dat1_name, "&", dat2_name))
        fit <- eulerr::euler(combo)
        plot <- plot(fit,
                     fills = list(fill = c("#dceaf2", "#2A5773"),
                                  alpha = 0.7),
                     labels = list(font = 2))
        return(plot)
      }

      # Generate a list
      x <- list(dat1_sub, dat2_sub)
      names(x) <- c(dat1_name, dat2_name)

      # Plot list
      plot <- ggvenn::ggvenn(
        x,
        fill_color = c("#dceaf2", "#2A5773"),
        stroke_size = 0.5,
        set_name_size = 5
      )
      return(plot)
    }
  }

context("check-output")
library(testthat)
library(overviewR)


test_that("overview_tab() returns a data frame", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  expect_is(output_table, "data.frame")

  output_table_complex <-
    overview_tab(
      dat = toydata,
      id = ccode,
      time = list(
        year = toydata$year,
        month = toydata$month,
        day = toydata$day
      ),
      complex_date = TRUE
    )
  expect_is(output_table_complex, "data.frame")
})

test_that("overview_tab() returns a dataframe with correct number of rows", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  expect_equal(nrow(output_table), length(unique(toydata$ccode)))
})

test_that("overview_tab() returns a dataframe with correct number of rows
          if there are duplicates", {
  data_test <- data.frame(
    ccode = c("RWA", "RWA", "BDI"),
    year = c(1990, 1990, 2000)
  )
  output_table <-
    overview_tab(dat = data_test, id = ccode, time = year)
  expect_is(output_table, "data.frame")
})

test_that("overview_tab() works on a dataframe that is already in the correct
          format", {
  df_com <- data.frame(
    # Countries
    ccode = c(
      rep("RWA", 4),
      rep("AGO", 8),
      rep("BEN", 2),
      rep("GBR", 5),
      rep("FRA", 3)
    ),
    # Time frame
    year =
      c(
        seq(1990, 1995),
        seq(1990, 1992),
        seq(1995, 1999),
        seq(1991, 1999, by = 2),
        seq(1993, 1999, by = 3)
      )
  )
  output_table <-
    overview_tab(dat = df_com, id = ccode, time = year)
  expect_equal(nrow(output_table), 5)
})


test_that("Get a warning message from overview_tab", {
  data_test <- data.frame(
    countries = c("RWA", NA, NA),
    years = c(1990, 2000, 2001)
  )
  expect_warning(overview_tab(data_test, id = countries, time = years))
})


test_that("check output of overview_latex", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  input_output <- overview_latex(output_table, save_out = FALSE)
  testthat::expect_null(print(input_output))
})

test_that("check output of overview_latex with font size", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  input_output <-
    overview_latex(output_table, save_out = FALSE, fontsize = "small")
  testthat::expect_null(print(input_output))
})

test_that("check output of overview_latex with save_out", {
  testthat::skip_on_cran()
  output_table <-
    overview_tab(dat = toydata, id = ccode, time = year)
  temp <- tempfile()
  on.exit(unlink(temp), add = TRUE)
  tex_output <-
    overview_latex(output_table,
      save_out = TRUE,
      file_path = paste0(temp, "output.tex")
    )
  testthat::expect_null(print(tex_output))
})

test_that("check output of overview_latex for crosstab", {
  output_cross <-
    overview_crosstab(
      dat = toydata,
      id = ccode,
      time = year,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 27000,
      threshold2 = 25000
    )
  input_output <- overview_latex(output_cross,
    crosstab = TRUE,
    save_out = FALSE
  )
  testthat::expect_null(print(input_output))
})

test_that("check output of overview_latex for crosstab with unique ids", {
  modified <- toydata %>%
    dplyr::ungroup() %>%
    dplyr::group_by(ccode, year) %>%
    dplyr::summarise(
      population = mean(population, na.rm = TRUE),
      gdp = mean(gdp, na.rm = TRUE)
    ) %>%
    dplyr::ungroup()

  output_cross <-
    overview_crosstab(
      dat = modified,
      id = ccode,
      time = year,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 27000,
      threshold2 = 25000
    )
  input_output <- overview_latex(output_cross,
    crosstab = TRUE,
    save_out = FALSE
  )
  testthat::expect_null(print(input_output))
})

test_that("check output of overview_latex for crosstab with save_out", {
  testthat::skip_on_cran()
  output_cross <-
    overview_crosstab(
      dat = toydata,
      id = ccode,
      time = year,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 27000,
      threshold2 = 25000
    )
  temp <- tempfile()
  on.exit(unlink(temp), add = TRUE)
  tex_output <-
    overview_latex(
      output_cross,
      crosstab = TRUE,
      save_out = TRUE,
      file_path = paste0(temp, "output.tex")
    )
  testthat::expect_null(print(tex_output))
})


test_that("Get a warning message from overview_crosstab", {
  testthat::skip_on_cran()
  data_test <- toydata %>%
    dplyr::mutate(ccode = ifelse(ccode == "RWA", NA, ccode))
  expect_warning(
    overview_crosstab(
      data_test,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 27000,
      threshold2 = 25000,
      id = ccode,
      time = year
    )
  )
})

test_that("Get an error message", {
  df_combined <- data.frame( # Countries
    countries = c(
      rep("RWA", 4),
      rep("AGO", 8),
      rep("BEN", 2),
      rep("GBR", 5),
      rep("FRA", 3)
    )
  )
  expect_error(
    overview_latex(df_combined),
    "Data frame requires two columns that represent the time and
        scope dimension of the data"
  )
})

test_that("check output of for crosstab", {
  testthat::skip_on_cran()

  toydata_no_dup <-
    toydata %>%
    dplyr::select(ccode, year, population, gdp) %>%
    dplyr::group_by(ccode, year) %>%
    dplyr::mutate(
      ccode = dplyr::first(ccode),
      year = dplyr::first(year),
      population = mean(population),
      gdp = mean(gdp)
    ) %>%
    dplyr::mutate(ccode = ifelse(year == 1990 & ccode == "RWA", NA, ccode)) %>%
    dplyr::ungroup() %>%
    dplyr::distinct()

  expect_warning(
    overview_crosstab(
      dat = toydata_no_dup,
      id = ccode,
      time = year,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 27000,
      threshold2 = 25000
    )
  )
})


test_that("Get a warning message", {
  data_test <- data.frame(
    countries = c("RWA", "BDI"),
    years = c(1990, 2000)
  )
  expect_warning(overview_latex(data_test))
})

test_that("overview_crosstab() returns a data frame", {
  output_crosstab <- overview_crosstab(
    dat = toydata,
    cond1 = gdp,
    cond2 = population,
    threshold1 = 25000,
    threshold2 = 27000,
    id = ccode,
    time = year
  )
  expect_is(output_crosstab, "data.frame")
})

test_that("overview_crosstab() works on a dataframe that is already in the
correct format", {
  df_com <- data.frame(
    # Countries
    ccode = c(
      rep("RWA", 4),
      rep("AGO", 8),
      rep("BEN", 2),
      rep("GBR", 5),
      rep("FRA", 3)
    ),
    # Time frame
    year =
      c(
        seq(1990, 1993),
        seq(1990, 1997),
        seq(1995, 1996),
        seq(1991, 1995),
        seq(1993, 1999, by = 3)
      ),
    population =
      seq(1, 44, by = 2),
    gdp =
      seq(1, 44, by = 2)
  )
  output_cross <-
    overview_crosstab(
      dat = df_com,
      id = ccode,
      time = year,
      cond1 = population,
      cond2 = gdp,
      threshold1 = 20,
      threshold2 = 10
    )
  expect_equal(nrow(output_cross), 2)
})

test_that("check output of overview_na", {
  plot_na <- overview_na(dat = toydata)
  testthat::expect_is(plot_na, "ggplot")
  plot_na_abs <- overview_na(dat = toydata, perc = FALSE)
  testthat::expect_is(plot_na_abs, "ggplot")
})

test_that("check output of overview_na with row_wise", {
  plot_na_row <- overview_na(dat = toydata, row_wise = TRUE)
  testthat::expect_is(plot_na_row, "ggplot")
  plot_na_abs_row <-
    overview_na(
      dat = toydata,
      perc = FALSE,
      row_wise = TRUE
    )
  testthat::expect_is(plot_na_abs_row, "ggplot")
})

test_that("check output of overview_overlap", {
  toydata2 <- toydata
  plot_overlap_bar <-
    overview_overlap(
      dat1 = toydata,
      dat2 = toydata2,
      dat1_id = ccode,
      dat2_id = ccode,
      plot_type = "bar"
    )
  testthat::expect_is(plot_overlap_bar, "ggplot")
  plot_overlap_venn <-
    overview_overlap(
      dat1 = toydata,
      dat2 = toydata2,
      dat1_id = ccode,
      dat2_id = ccode,
      plot_type = "venn"
    )
  testthat::expect_is(plot_overlap_venn, "ggplot")
})


test_that("overview_na() returns a data frame", {
  overview_na_df <- overview_na(
    dat = toydata,
    row_wise = TRUE,
    add = TRUE
  )
  expect_is(overview_na_df, "data.frame")
})

test_that("check output of overview_heat", {
  plot_heat <-
    overview_heat(toydata, ccode, year, perc = TRUE, exp_total = 12)
  testthat::expect_is(plot_heat, "ggplot")
  plot_heat_abs <- overview_heat(toydata, ccode, year, perc = FALSE)
  testthat::expect_is(plot_heat_abs, "ggplot")
})

test_that("check output of overview_heat with label FALSE", {
  plot_heat_no_lab <- overview_heat(
    toydata,
    ccode,
    year,
    perc = TRUE,
    label = FALSE,
    exp_total = 12
  )
  testthat::expect_is(plot_heat_no_lab, "ggplot")
})

test_that("check output of overview_heat with label FALSE and no perc", {
  plot_heat_abs_lab_false <-
    overview_heat(toydata, ccode, year,
      perc = FALSE,
      label = FALSE
    )
  testthat::expect_is(plot_heat_abs_lab_false, "ggplot")
})

test_that("check output of overview_plot", {
  plot <- overview_plot(dat = toydata, id = ccode, time = year)
  testthat::expect_is(plot, "ggplot")
})

test_that("check output of overview_plot", {
  plot <-
    overview_plot(
      dat = toydata,
      id = ccode,
      time = year,
      asc = FALSE
    )
  testthat::expect_is(plot, "ggplot")
})

test_that("check output of overview_plot with color", {
  plot <-
    overview_plot(
      dat = toydata,
      id = ccode,
      time = year,
      color = population
    )
  testthat::expect_is(plot, "ggplot")
})

test_that("check output of overview_plot with color", {
  plot <-
    overview_plot(
      dat = toydata,
      id = ccode,
      time = year,
      color = population,
      asc = FALSE
    )
  testthat::expect_is(plot, "ggplot")
})




test_that("check output of overview_crossplot", {
  plot_cross <-
    overview_crossplot(toydata, ccode, year, gdp, population, 25000, 27000)
  testthat::expect_is(plot_cross, "ggplot")
  plot_cross_col <-
    overview_crossplot(toydata, ccode, year, gdp, population, 25000, 27000,
      color = TRUE
    )
  testthat::expect_is(plot_cross_col, "ggplot")
  plot_cross_lab <-
    overview_crossplot(toydata, ccode, year, gdp, population, 25000, 27000,
      label = TRUE
    )
  testthat::expect_is(plot_cross_lab, "ggplot")
  plot_cross_lab_col <-
    overview_crossplot(
      toydata,
      ccode,
      year,
      gdp,
      population,
      25000,
      27000,
      label = TRUE,
      color = TRUE
    )
  testthat::expect_is(plot_cross_lab, "ggplot")
})


test_that("check output of overview_crossplot without dups", {
  toydata_no_dup <-
    toydata %>%
    dplyr::select(ccode, year, population, gdp) %>%
    dplyr::group_by(ccode, year) %>%
    dplyr::mutate(
      ccode = dplyr::first(ccode),
      year = dplyr::first(year),
      population = mean(population),
      gdp = mean(gdp)
    ) %>%
    dplyr::ungroup() %>%
    dplyr::distinct()

  plot_cross <-
    overview_crossplot(toydata_no_dup, ccode, year, gdp, population, 25000, 27000)
  testthat::expect_is(plot_cross, "ggplot")
  plot_cross_col <-
    overview_crossplot(toydata_no_dup, ccode, year, gdp, population, 25000, 27000,
      color = TRUE
    )
  testthat::expect_is(plot_cross_col, "ggplot")
  plot_cross_lab <-
    overview_crossplot(toydata_no_dup, ccode, year, gdp, population, 25000, 27000,
      label = TRUE
    )
  testthat::expect_is(plot_cross_lab, "ggplot")
  plot_cross_lab_col <-
    overview_crossplot(
      toydata_no_dup,
      ccode,
      year,
      gdp,
      population,
      25000,
      27000,
      label = TRUE,
      color = TRUE
    )
  testthat::expect_is(plot_cross_lab, "ggplot")
})



test_that("check output of overview_crossplot with label FALSE", {
  plot_cross_no_lab <-
    overview_crossplot(toydata, ccode, year, gdp, population, 25000, 27000,
      label = FALSE
    )
  testthat::expect_is(plot_cross_no_lab, "ggplot")
  plot_cross_no_lab_but_col <-
    overview_crossplot(
      toydata,
      ccode,
      year,
      gdp,
      population,
      25000,
      27000,
      label = FALSE,
      color = TRUE
    )
  testthat::expect_is(plot_cross_no_lab_but_col, "ggplot")
})



test_that("check output of overview_crossplot with no color", {
  plot_cross_no_lab_no_col <-
    overview_crossplot(
      toydata,
      ccode,
      year,
      gdp,
      population,
      25000,
      27000,
      color = FALSE,
      label = FALSE
    )
  testthat::expect_is(plot_cross_no_lab_no_col, "ggplot")
  plot_cross_no_col <-
    overview_crossplot(toydata, ccode, year, gdp, population, 25000, 27000,
      color = FALSE
    )
  testthat::expect_is(plot_cross_no_col, "ggplot")
})

test_that("for time$day in overview_tab", {
  expect_error(overview_tab(dat = toydata, id = ccode, time = list(year = toydata$year, month = toydata$month, day = NULL), complex_date = TRUE))
})

test_that("overview_plot accepts a literal color string (asc = TRUE)", {
  plot <- overview_plot(dat = toydata, id = ccode, time = year,
                        color = "steelblue")
  testthat::expect_is(plot, "ggplot")
})

test_that("overview_plot accepts a literal color string (asc = FALSE)", {
  plot <- overview_plot(dat = toydata, id = ccode, time = year,
                        color = "steelblue", asc = FALSE)
  testthat::expect_is(plot, "ggplot")
})

test_that("overview_na warns when month column contains NAs", {
  dat_na <- toydata
  dat_na$month[1:5] <- NA
  expect_warning(
    overview_na(dat_na),
    regexp = "month"
  )
})

test_that("overview_na does not warn when no month/day NAs present", {
  expect_no_warning(overview_na(toydata))
})

test_that("overview_overlap proportional Venn requires eulerr", {
  testthat::skip_if_not_installed("eulerr")
  toydata2 <- toydata[toydata$year > 1992, ]
  result <- overview_overlap(
    dat1 = toydata, dat2 = toydata2,
    dat1_id = ccode, dat2_id = ccode,
    plot_type = "venn", proportional = TRUE
  )
  testthat::expect_s3_class(result, "eulergram")
})

test_that("overview_overlap errors informatively when eulerr missing", {
  testthat::skip_if(requireNamespace("eulerr", quietly = TRUE),
                    "eulerr is installed; skipping absence test")
  toydata2 <- toydata[toydata$year > 1992, ]
  expect_error(
    overview_overlap(
      dat1 = toydata, dat2 = toydata2,
      dat1_id = ccode, dat2_id = ccode,
      plot_type = "venn", proportional = TRUE
    ),
    regexp = "eulerr"
  )
})

test_that("overview_markdown returns an invisible character string (tab)", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  result <- overview_markdown(obj = output_table)
  testthat::expect_is(result, "character")
  testthat::expect_true(grepl("Sample", result))
  testthat::expect_true(grepl("Time frame", result))
})

test_that("overview_markdown returns correct output for crosstab", {
  output_cross <- overview_crosstab(
    dat = toydata, id = ccode, time = year,
    cond1 = gdp, cond2 = population,
    threshold1 = 25000, threshold2 = 27000
  )
  result <- overview_markdown(obj = output_cross, crosstab = TRUE,
                               cond1 = "GDP", cond2 = "Population")
  testthat::expect_is(result, "character")
  testthat::expect_true(grepl("GDP", result))
  testthat::expect_true(grepl("Population", result))
})

test_that("overview_markdown writes to file with save_out = TRUE", {
  testthat::skip_on_cran()
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  temp <- tempfile(fileext = ".md")
  on.exit(unlink(temp), add = TRUE)
  overview_markdown(obj = output_table, save_out = TRUE, file_path = temp)
  testthat::expect_true(file.exists(temp))
  content <- readLines(temp)
  testthat::expect_true(any(grepl("Sample", content)))
})

test_that("overview_markdown errors on wrong column count", {
  bad_df <- data.frame(a = 1:3, b = 1:3, c = 1:3)
  expect_error(overview_markdown(obj = bad_df), regexp = "two columns")
})
# test_that("check output of overview_crossplot with unique observations", {
#   modified <- toydata %>%
#     dplyr::ungroup() %>%
#     dplyr::group_by(ccode, year) %>%
#     dplyr::summarise(population = mean(population, na.rm=TRUE),
#                      gdp = mean(gdp, na.rm=TRUE)) %>%
#     dplyr::ungroup()
#
#
#   plot_cross <-
#     overview_crossplot(modified, ccode, year, cond1 = gdp, cond2 = population, threshold1 = 25000, threshold2 = 27000)
#   testthat::expect_is(plot_cross, "ggplot")
#   plot_cross_col <-
#     overview_crossplot(modified, ccode, year, cond1 = gdp, cond2 = population, threshold1 = 25000, threshold2 = 27000,
#                        color = TRUE)
#   testthat::expect_is(plot_cross_col, "ggplot")
#   plot_cross_lab <-
#     overview_crossplot(modified, ccode, year, cond1 = gdp, cond2 = population, threshold1 = 25000, threshold2 = 27000,
#                        label = TRUE)
#   testthat::expect_is(plot_cross_lab, "ggplot")
#   plot_cross_lab_col <-
#     overview_crossplot(modified, ccode, year, cond1 = gdp, cond2 = population, threshold1 = 25000, threshold2 = 27000,
#                        label = TRUE, color = TRUE)
#   testthat::expect_is(plot_cross_lab, "ggplot")
#
#
# })
#
# test_that("check output of overview_overlap", {
#   plot <-
#     overview_overlap(
#       dat1 = toydata,
#       dat2 = toydata,
#       dat1_id = ccode,
#       dat2_id = ccode
#     )
#   testthat::expect_is(plot, "ggplot")
# })

#' @title .overview_tab
#'
#' @description Internal function that calculates the `overview_tab` for data.table objects
#'
#' @param dat The data set
#' @param id The scope (e.g., country codes or individual IDs). The axis is
#'     ordered in ascending order by default.
#' @param time The time (e.g., time periods given by years, months, ...)
#' @param perc If FALSE (default) plot returns the total number of observations
#'     per time-scope-unit. If TRUE, it returns the number of observations per
#'     time-scope-unit in percentage
#' @param exp_total Expected total number of observations (i.e. maximum)
#'     for time unit.
#' @param xaxis Label of your x axis ("Time frame" is default)
#' @param yaxis Label of your y axis ("Sample" is default)
#' @param col_low Hex color code for the lowest value (default is "#dceaf2")
#' @param col_high Hex color code for the lowest value (default is "#2A5773")
#' @param label If TRUE (default), the total number of observations/percentages
#'     of observations are displayed. If FALSE, it returns no labels.
#' @param theme_plot Previously generated theme
#' @param col_names The column names (containing id and time)
#' @return A ggplot

.overview_heat <-
  function(dat = NULL,
           id = NULL,
           time = NULL,
           label = FALSE,
           perc = FALSE,
           col_low = NULL,
           col_high = NULL,
           xaxis = NULL,
           yaxis = NULL,
           theme_plot = NULL,
           exp_total = NULL,
           col_names = NULL) {
    if (perc) {
      dat_agg <- dat %>%
        dplyr::group_by(!!id, !!time) %>%
        dplyr::mutate(
          count = dplyr::n(),
          total = count / exp_total
        )
    } else {
      dat_agg <- dat %>%
        dplyr::group_by(!!id, !!time) %>%
        dplyr::mutate(count = dplyr::n())
    }
    # Plot the result
    plot <- dat_agg %>%
      dplyr::ungroup() %>%
      dplyr::group_by(!!id) %>%
      ggplot2::ggplot(ggplot2::aes(factor(!!time), !!id)) +
      ggplot2::geom_tile(ggplot2::aes(fill = count), colour = "white") +
      ggplot2::scale_fill_gradient(low = col_low, high = col_high) +
      ggplot2::ylab(yaxis) +
      ggplot2::xlab(xaxis) +
      ggplot2::scale_y_discrete(limits = rev) +
      theme_plot

    # If there is a label, add it
    if (label & !perc) {
      plot <- plot +
        ggplot2::geom_text(ggplot2::aes(label = round(count, 1)), size = 3.3)
    }
    if (perc) {
      plot <- plot +
        ggplot2::geom_text(ggplot2::aes(label = paste(round(100 * total, 2),
          "%",
          sep = ""
        )),
        size = 3.3
        )
    }
    return(plot)
  }

#' @title overview_add_na_output
#'
#' @description Function used in `overview_na` to generate a new data frame with
#'     na_count and percentage share of NAs for each row
#'
#' @param dat_result Data.frame from `overview_na`
#' @param dat Data frame
#' @return The function returns a data set that has the information
#'     on the row-wise NA share

overview_add_na_output <- function(dat_result = NULL, dat = NULL) {
  if (any(class(dat) == "data.table")) {
    dat_result <- dat_result[, .(na_count, percentage)]
    dat_with_na <- cbind(dat, dat_result)
    return(dat_with_na)
  } else {
    dat_result <- dat_result %>%
      dplyr::select(na_count, percentage)
    dat_with_na <- cbind(dat, dat_result)
    return(dat_with_na)
  }
}

#' @title overview_tab_df
#'
#' @description Internal function that calculates the `overview_tab` for data.frame objects
#'
#' @param dat2 Your data set
#' @param dat Your data set
#' @param id Scope (e.g., country codes or individual IDs)
#' @param time Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).
#' @return A data.frame

overview_tab_df <- function(dat2 = NULL,
                            dat = NULL,
                            id = NULL,
                            time = NULL) {
  if (nrow(dat2) == nrow(dat)) {
    # Check the length of unique observations (based on time and id) in the
    # data set
    # We need this for the next check
    length_nodup <- dat %>%
      dplyr::distinct(!!id, !!time, .keep_all = TRUE)

    # Check if data set only has unique observations
    if (nrow(length_nodup) == nrow(dat)) {
      # Apply it to the data
      tab <- dat %>%
        # Select important variables
        dplyr::select(!!id, !!time) %>%
        # Group data
        dplyr::group_by(!!id, !!time) %>%
        # Arrange the data
        dplyr::arrange(!!id, !!time) %>%
        # Only get distinct IDs
        dplyr::distinct(!!id) %>%
        # Group by ID
        dplyr::group_by(!!id) %>%
        # Apply function generated above
        dplyr::mutate(time_frame = paste(find_int_runs(!!time),
          collapse = ", "
        )) %>%
        # Subset it to only one distinct country
        dplyr::distinct(!!id, time_frame)

      # Return object
      return(tab)
    }
    # If this is not the case, we need to aggregate the data
    else {
      dat2 <- dat %>%
        dplyr::select(!!id, !!time) %>%
        dplyr::group_by(!!id, !!time) %>%
        dplyr::distinct(!!id, !!time)

      # Apply code from above to the new data
      # Apply it to the data
      tab2 <- dat2 %>%
        # Select important variables
        dplyr::select(!!id, !!time) %>%
        # # Group data
        dplyr::group_by(!!id, !!time) %>%
        # Arrange the data
        dplyr::arrange(!!id, !!time) %>%
        # Only get distinct IDs
        dplyr::distinct(!!id) %>%
        # Group by ID
        dplyr::group_by(!!id) %>%
        # Apply function generated above
        dplyr::mutate(time_frame = paste(find_int_runs(!!time),
          collapse = ", "
        )) %>%
        # Subset it to only one distinct country
        dplyr::distinct(!!id, time_frame)

      return(tab2)
    }
  }
}

#' @title overview_crossplot
#'
#' @description This function plots a ggplot to visualize a cross table plot.
#'
#' @param dat Your data set
#' @param cond1 Variable that describes the first condition
#' @param cond2 Variable that describes the second condition
#' @param threshold1 A threshold for \code{cond1}
#' @param threshold2 A threshold for \code{cond2}
#' @param id Your scope (e.g., country codes or individual IDs). If the id
#'     variable contains NAs, they will not be included in the plot.
#' @param time Your time (e.g., time periods given by years, months, ...)
#' @param xaxis Label of the x axis ("Condition 1" is default)
#' @param yaxis Label of the y axis ("Condition 2" is default)
#' @param label Label of the observations. Overlapping labels are
#'     avoided by using 'ggrepel'
#' @param color Color of the different observation groups
#' @param dot_size Option argument that defines the dot size (default is 2)
#' @param fontsize If label is TRUE, the fontsize arguments allows to define the text of the labels (the default is 2.5)
#' @return A ggplot figure that presents the sample information visually
#'     in a cross table
#' @examples
#' data(toydata)
#' overview_crossplot(
#'   dat = toydata,
#'   cond1 = gdp,
#'   cond2 = population,
#'   threshold1 = 25000,
#'   threshold2 = 27000,
#'   id = ccode,
#'   time = year
#' )
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom ggplot2 ggplot
#' @importFrom ggrepel geom_text_repel




overview_crossplot <-
  function(dat,
           id,
           time,
           cond1,
           cond2,
           threshold1,
           threshold2,
           xaxis = "Condition 1",
           yaxis = "Condition 2",
           label = FALSE,
           color = FALSE,
           dot_size = 2,
           fontsize = 2.5) {
    # Create a theme for the plot
    theme_plot <- ggplot2::theme(
      # get rid of panel grids
      axis.line = ggplot2::element_blank(),
      axis.ticks.y = ggplot2::element_blank(),
      axis.ticks.x = ggplot2::element_blank(),
      panel.border = ggplot2::element_blank(),
      panel.grid.major.x = ggplot2::element_line(
        color = "grey90",
        linetype = "dashed"
      ),
      # Change plot and panel background
      plot.background = ggplot2::element_rect(fill = "white"),
      panel.background = ggplot2::element_rect(fill = "white"),
      # Change legend
      legend.direction = "horizontal",
      legend.position = "bottom",
      legend.background = ggplot2::element_rect(fill = "white", color = NA),
      legend.key = ggplot2::element_rect(color = "white", fill = "white"),
      legend.title = ggplot2::element_blank(),
      # Change text
      plot.caption = ggplot2::element_text(size = 5),
      axis.text = ggplot2::element_text(
        face = "plain",
        color = "black",
        size = 8
      ),
      text = ggplot2::element_text(
        size = 10,
        face = "plain"
      )
    )

    id <- dplyr::enquo(id)
    time <- dplyr::enquo(time)
    cond1 <- dplyr::enquo(cond1)
    cond2 <- dplyr::enquo(cond2)

    # Check the length of unique observations
    # (based on time and id) in the data set
    # We need this for the next check
    length_nodup <- dat %>%
      dplyr::distinct(!!id, !!time, .keep_all = TRUE)

    # Check if data set only has unique observations
    if (nrow(length_nodup) == nrow(dat)) {
      red <- dat %>%
        dplyr::ungroup() %>%
        dplyr::group_by(!!id, !!time) %>%
        dplyr::summarise(
          cond1_mean = mean(!!cond1),
          cond2_mean = mean(!!cond2)
        ) %>%
        dplyr::ungroup()

      cond1_mean <- red$cond1_mean
      cond1_mean <- dplyr::enquo(cond1_mean)

      cond2_mean <- red$cond2_mean
      cond2_mean <- dplyr::enquo(cond2_mean)

      dat_red <- dat %>%
        dplyr::mutate(
          c1 = ifelse(!!cond1 >= threshold1, 1, 0),
          c2 = ifelse(!!cond2 >= threshold2, 1, 0)
        ) %>%
        dplyr::group_by(c1, c2) %>%
        dplyr::select(!!id, !!time, !!cond1, !!cond2, c1, c2) %>%
        dplyr::mutate(
          quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
          quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
          quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
          quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
        ) %>%
        dplyr::ungroup() %>%
        dplyr::mutate(
          grp = ifelse(quart1 == 1, 1,
            ifelse(
              quart2 == 1, 2,
              ifelse(quart3 == 1, 3,
                ifelse(quart4 == 1, 4, 0)
              )
            )
          ),
          text = paste0(!!id, !!time)
        )


      if (color == TRUE & label == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(
            x = !!cond1_mean,
            y = !!cond2_mean,
            label = text
          )) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size, ggplot2::aes(color = factor(grp))) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggrepel::geom_text_repel(size = fontsize) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
      if (color == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(x = !!cond1_mean, y = !!cond2_mean)) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size, ggplot2::aes(color = factor(grp))) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
      if (label == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(
            x = !!cond1_mean,
            y = !!cond2_mean,
            label = text
          )) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggrepel::geom_text_repel(size = fontsize) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      } else {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(x = !!cond1_mean, y = !!cond2_mean)) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
    }

    # If this is not the case, we need to aggregate the data
    else {
      red <- dat %>%
        dplyr::ungroup() %>%
        dplyr::group_by(!!id, !!time) %>%
        dplyr::summarise(
          cond1_mean = mean(!!cond1),
          cond2_mean = mean(!!cond2)
        ) %>%
        dplyr::ungroup()

      cond1_mean <- red$cond1_mean
      cond1_mean <- dplyr::enquo(cond1_mean)

      cond2_mean <- red$cond2_mean
      cond2_mean <- dplyr::enquo(cond2_mean)

      # Apply the code to the code above
      dat_red <- red %>%
        dplyr::mutate(
          c1 = ifelse(!!cond1_mean >= threshold1, 1, 0),
          c2 = ifelse(!!cond2_mean >= threshold2, 1, 0)
        ) %>%
        dplyr::group_by(c1, c2) %>%
        dplyr::mutate(
          quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
          quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
          quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
          quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
        ) %>%
        dplyr::ungroup() %>%
        dplyr::mutate(
          grp = ifelse(quart1 == 1, 1,
            ifelse(
              quart2 == 1, 2,
              ifelse(quart3 == 1, 3,
                ifelse(quart4 == 1, 4, 0)
              )
            )
          ),
          text = paste0(!!id, !!time)
        )

      if (color == TRUE & label == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(
            x = !!cond1_mean,
            y = !!cond2_mean,
            label = text
          )) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size, ggplot2::aes(color = factor(grp))) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggrepel::geom_text_repel(size = fontsize) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
      if (color == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(x = !!cond1_mean, y = !!cond2_mean)) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size, ggplot2::aes(color = factor(grp))) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
      if (label == TRUE) {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(
            x = !!cond1_mean,
            y = !!cond2_mean,
            label = text
          )) +
          ggplot2::geom_point(alpha = 0.5, size = dot_size) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggrepel::geom_text_repel(size = fontsize) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      } else {
        plot <- dat_red %>%
          ggplot2::ggplot(ggplot2::aes(x = !!cond1_mean, y = !!cond2_mean)) +
          ggplot2::geom_point(alpha = 0.5) +
          ggplot2::geom_vline(xintercept = threshold1) +
          ggplot2::geom_hline(yintercept = threshold2) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot +
          ggplot2::theme(legend.position = "none")

        return(plot)
      }
    }
  }

#' @title overview_markdown
#'
#' @description Produces a Markdown table output for objects obtained via
#'    \code{overview_tab} and \code{overview_crosstab}
#'
#' @param obj Overview object produced by \code{overview_tab} or
#'     \code{overview_crosstab}
#' @param title Optional title printed as a Markdown heading above the table.
#'     Defaults to \code{"Time and scope of the sample"}.
#' @param id The header of the left column (default is \code{"Sample"}).
#'     Ignored when \code{crosstab = TRUE}.
#' @param time The header of the right column (default is \code{"Time frame"}).
#'     Ignored when \code{crosstab = TRUE}.
#' @param crosstab Logical. If \code{TRUE} produces a cross-table output.
#'     Default is \code{FALSE}.
#' @param cond1 Label for the first condition. Ignored when
#'     \code{crosstab = FALSE}.
#' @param cond2 Label for the second condition. Ignored when
#'     \code{crosstab = FALSE}.
#' @param save_out Logical. If \code{TRUE} writes the output to a file.
#'     Default is \code{FALSE}.
#' @param file_path Path (including file name with \code{.md} extension) where
#'     the output is stored when \code{save_out = TRUE}.
#' @return Invisibly returns a character string with the Markdown table. The
#'     table is also printed to the console (unless \code{save_out = TRUE}).
#' @examples
#' data(toydata)
#'
#' overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
#' overview_markdown(obj = overview_object)
#'
#' overview_ct_object <- overview_crosstab(
#'   dat = toydata,
#'   cond1 = gdp,
#'   cond2 = population,
#'   threshold1 = 25000,
#'   threshold2 = 27000,
#'   id = ccode,
#'   time = year
#' )
#' overview_markdown(
#'   obj = overview_ct_object,
#'   crosstab = TRUE,
#'   cond1 = "GDP",
#'   cond2 = "Population"
#' )
#' @export

overview_markdown <-
  function(obj,
           title = "Time and scope of the sample",
           id = "Sample",
           time = "Time frame",
           crosstab = FALSE,
           cond1 = "Condition 1",
           cond2 = "Condition 2",
           save_out = FALSE,
           file_path = "") {

    obj <- as.data.frame(obj)

    if (ncol(obj) != 2) {
      stop(
        "Data frame requires exactly two columns. ",
        "An overview_tab or overview_crosstab object is required."
      )
    }

    if (crosstab == FALSE) {
      header <- paste0("| ", id, " | ", time, " |")
      sep    <- paste0("|", strrep("-", nchar(id) + 2), "|",
                       strrep("-", nchar(time) + 2), "|")
      rows   <- paste0("| ", obj[[1]], " | ", obj[[2]], " |",
                       collapse = "\n")
      out <- paste(
        paste0("## ", title),
        header, sep, rows,
        sep = "\n"
      )
    } else {
      # 2x2 cross-table layout
      col_header <- paste0(
        "| | **", cond1, "**: Fulfilled | **", cond1, "**: Not fulfilled |"
      )
      sep <- paste0("|---|---|---|")
      row1 <- paste0(
        "| **", cond2, "**: Fulfilled | ", obj[1, 1], " | ", obj[1, 2], " |"
      )
      row2 <- paste0(
        "| **", cond2, "**: Not fulfilled | ", obj[2, 1], " | ",
        obj[2, 2], " |"
      )
      out <- paste(
        paste0("## ", title),
        col_header, sep, row1, row2,
        sep = "\n"
      )
    }

    if (save_out) {
      writeLines(out, con = file_path)
    } else {
      cat(out, "\n")
    }

    invisible(out)
  }

#' @title .overview_tab
#'
#' @description Internal function that calculates the `overview_tab` for data.table objects
#'
#' @param dat Your data set
#' @param id Scope (e.g., country codes or individual IDs)
#' @param time Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).
#' @param col_names The column names (containing id and time)
#' @return A data.table

.overview_tab <- function(dat = NULL,
                          id = NULL,
                          time = NULL,
                          col_names = NULL) {
  return_cols <- c(id, "time_frame")
  dat <-
    unique(unique(dat[, ..col_names])[, list(time_frame = paste(find_int_runs(get(time)), collapse = ", ")), by = get(id)])
  data.table::setnames(x = dat, old = "get", new = id)

  return(dat)
}

#' @title find_int_runs
#'
#' @description Function used in `overview_tab` to find running integers
#'
#' @param run Variable (integer) that should be checked for consecutive values
#' @return The function returns a data set

# Check for consecutive numbers and collapse them with "-"
# Inspired here: https://bit.ly/3ebZo5j
find_int_runs <- function(run = NULL) {
  rundiff <- c(1, diff(run))
  difflist <- split(run, cumsum(rundiff != 1))
  unlist(lapply(difflist, function(x) {
    if (length(x) %in% 1) {
      as.character(x)
    } else {
      paste(x[1], "-", x[length(x)])
    }
  }), use.names = FALSE)
}

#' @title overview_latex
#'
#' @description Produces a 'LaTeX' output for output obtained via
#'    \code{overview_tab} and \code{overview_crosstab}
#'
#' @param obj Overview object produced by overview_tab or overview_crosstab
#' @param title Caption of the table (default is "Time and scope of the sample")
#' @param id The name of the left column (default is "Sample"), will be ignored
#'     if crosstab is TRUE
#' @param time The name of the right column (default is ("Time frame")), will
#'     be ignored if \code{crosstab} is TRUE
#' @param crosstab Logical argument, if TRUE produces a \code{crosstab} output,
#'     default is FALSE
#' @param cond1 Description for the first condition (character), will be
#'     ignored if \code{crosstab} is FALSE. This should correspond to the input
#'     for \code{cond1} in \code{overview_crosstab}
#' @param cond2 Description for the second condition (character), will be
#'     ignored if \code{crosstab} is FALSE. This should correspond to the input
#'     for \code{cond2} in \code{overview_crosstab}
#' @param save_out Optional argument, exports the output table as a .tex
#'     file, default is FALSE
#' @param file_path Specifies the path and file name (.tex) where you store your output
#' @param label Specifies the label (default is "tab:tab1")
#' @param fontsize Specifies the font size (all 'LaTeX' font sizes such as
#'     "scriptsize" or "small" work)
#' @param path This argument is deprecated. Please use "file_path" instead and add the full path.
#' @param file This argument is deprecated. Please use "file_path" instead and add the full path.
#' @return A 'LaTeX' output that can either be copy-pasted in a text document or
#'     exported directed as a .tex file
#' @examples
#' data(toydata)
#'
#' overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
#' overview_latex(
#'   obj = overview_object,
#'   title = "Some nice title",
#'   crosstab = FALSE
#' )
#'
#'#' overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
#' overview_latex(
#'   obj = overview_object,
#'   title = "Some nice title",
#'   file_path = "some/path_to/your_output_file.tex"
#' )
#'
#' overview_ct_object <- overview_crosstab(
#'   dat = toydata,
#'   cond1 = gdp,
#'   cond2 = population,
#'   threshold1 = 25000,
#'   threshold2 = 27000,
#'   id = ccode,
#'   time = year
#' )
#' overview_latex(
#'   obj = overview_ct_object,
#'   title = "Some nice title for a cross tab",
#'   crosstab = TRUE,
#'   cond1 = "Name of first condition",
#'   cond2 = "Name of second condition"
#' )
#' @export overview_latex overview_latex
#' @importFrom dplyr "%>%"


overview_latex <-
  function(obj,
           title = "Time and scope of the sample",
           id = "Sample",
           time = "Time frame",
           crosstab = FALSE,
           cond1 = "Condition 1",
           cond2 = "Condition 2",
           save_out = FALSE,
           file_path,
           label = "tab:tab1",
           fontsize,
           file,
           path) {

    if (!missing("file") & !missing("path")){
      warning("Argument deprecated, use 'file_path' instead.
              The parameter 'file' and 'path' are combined to become 'file_path'.")
      file_path <- paste0(path, file)
    }

    obj <- as.matrix(obj)

    # Add a fontsize (if defined)
    if (missing(fontsize) == FALSE) {
      fontsize_mod <- paste0("\\", fontsize)
    } else {
      fontsize_mod <- ""
    }

    if (ncol(obj) != 2) {
      stop(
        "Data frame requires two columns that represent the time and
        scope dimension of the data. A overview_tab or overview_crosstab
        object is required."
      )
    }

    if (crosstab == FALSE) {
      if (nrow(obj) == 2) {
        warning(
          "Are you sure you want a table for time and scope conditions? For a
          crosstab, set option crosstab = TRUE"
        )
      }
      for (i in length(obj)) {
        begin_tab <-
          paste0(
            "% Overview table generated in ",
            version[["version.string"]],
            " using overviewR \n",
            "% Table created on ",
            as.character(Sys.Date()),
            "\n",
            "\\begin{table}[ht] \n \\centering \n \\caption{",
            title,
            "} \n",
            "\\label{",
            label,
            "} \n",
            fontsize_mod,
            "\n",
            "\\begin{tabular}{ll} \n \\hline \n",
            id,
            " & ",
            time,
            " \\\\ \\hline \n"
          )
        out <- paste0(obj[, 1], " & ", obj[, 2], " \\\\ \n")
        end_tab <-
          paste0("\\hline \n \\end{tabular} \n \\end{table} \n")
        if (save_out == FALSE) {
          cat(begin_tab, out, end_tab)
        }
        if (save_out == TRUE) {
          sink(file_path)
          cat(begin_tab, out, end_tab)
          sink()
        }
      }
    }
    if (crosstab == TRUE) {
      for (i in length(obj)) {
        begin_crosstab <- paste0(
          "% Overview table generated in ",
          version[["version.string"]],
          " using overviewR \n",
          "% Table created on ",
          as.character(Sys.Date()),
          "\n",
          "% Please add the following packages to your document preamble: \n",
          "% \\usepackage{multirow} \n",
          "% \\usepackage{tabularx} \n",
          "% \\newcolumntype{b}{X} \n",
          "% \\newcolumntype{s}{>{\\hsize=.5\\hsize}X} \n",
          "\\begin{table}[ht] \n",
          "\\caption{",
          title,
          "} \n",
          "\\label{",
          label,
          "} \n",
          fontsize_mod,
          "\n",
          "\\begin{tabularx}{\\textwidth}{ssbb} \n",
          "\\hline & & \\multicolumn{2}{c}{\\textbf{",
          cond1,
          "}} \\\\ \n",
          " & & \\textbf{Fulfilled} & \\textbf{Not fulfilled} \\\\ ",
          "\n \\hline \\\\ \n \\multirow{2}{*}{\\textbf{",
          cond2,
          "}} & \\textbf{Fulfilled} & \n"
        )
        cross_out1 <- paste0(obj[1, 1], " & ", obj[1, 2], "\\\\ ")

        mid_crosstab <-
          paste0("\n \\\\ \\hline \\\\ \n & \\textbf{Not fulfilled} & ")

        cross_out2 <- paste0(obj[2, 1], " & ", obj[2, 2], "\\\\ ")

        end_crosstab <-
          paste0("\\hline \\\\ \n \\end{tabularx} \n \\end{table} \n")
        if (save_out == FALSE) {
          cat(
            begin_crosstab,
            cross_out1,
            mid_crosstab,
            cross_out2,
            end_crosstab
          )
        }
      }
      if (save_out == TRUE) {
        sink(file_path)
        cat(
          begin_crosstab,
          cross_out1,
          mid_crosstab,
          cross_out2,
          end_crosstab
        )
        sink()
      }
    }
  }

overview_print <- overview_latex

#' @title overview_crosstab
#'
#' @description Sorts a data set conditionally in a cross table.
#'     This can be helpful to get a sense of the time and scope
#'     conditions of a data set. Note, if used with a data set that has multiple
#'     observations on the id-time unit, the function automatically aggregates
#'     this information using the mean.
#' @param dat A data set object
#' @param cond1 Variable that describes the first condition
#' @param cond2 Variable that describes the second condition
#' @param threshold1 A threshold for \code{cond1}
#' @param threshold2 A threshold for \code{cond2}
#' @param id Scope (e.g., country codes or individual IDs)
#' @param time Time (e.g., time periods given by years, months, ...)
#' @return A data frame object that contains a summary of the data set that can
#'       later be converted to a 'LaTeX' output using \code{overview_latex}
#' @examples
#' data(toydata)
#' overview_crosstab(
#'   dat = toydata,
#'   cond1 = gdp,
#'   cond2 = population,
#'   threshold1 = 25000,
#'   threshold2 = 27000,
#'   id = ccode,
#'   time = year
#' )
#' @export
#' @importFrom dplyr "%>%"

overview_crosstab <-
  function(dat,
           cond1,
           cond2,
           threshold1,
           threshold2,
           id,
           time) {
    id <- dplyr::enquo(id)
    time <- dplyr::enquo(time)
    cond1 <- dplyr::enquo(cond1)
    cond2 <- dplyr::enquo(cond2)

    # Check if there are NAs in the time or id variable
    # (and drop them but warn the user about it)
    dat2 <- dat %>%
      dplyr::filter(!is.na(!!id))

    if (nrow(dat2) == nrow(dat)) {
      # Check the length of unique observations
      # (based on time and id) in the data set
      # We need this for the next check
      length_nodup <- dat %>%
        dplyr::distinct(!!id, !!time, .keep_all = TRUE)

      # Check if data set only has unique observations
      if (nrow(length_nodup) == nrow(dat)) {
        red <- dat %>%
          dplyr::mutate(
            c1 = ifelse(!!cond1 >= threshold1, 1, 0),
            c2 = ifelse(!!cond2 >= threshold2, 1, 0)
          ) %>%
          dplyr::group_by(c1, c2) %>%
          dplyr::select(!!id, !!time, !!cond1, !!cond2, c1, c2) %>%
          dplyr::mutate(
            quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
            quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
            quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
            quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
          ) %>%
          dplyr::ungroup()

        quart1 <-
          red %>%
          dplyr::filter(quart1 == 1) %>%
          dplyr::select(!!id, !!time)
        quart2 <-
          red %>%
          dplyr::filter(quart2 == 1) %>%
          dplyr::select(!!id, !!time)
        quart3 <-
          red %>%
          dplyr::filter(quart3 == 1) %>%
          dplyr::select(!!id, !!time)
        quart4 <-
          red %>%
          dplyr::filter(quart4 == 1) %>%
          dplyr::select(!!id, !!time)

        quart1_1 <- overview_tab(quart1, !!id, !!time)
        quart1_1 <- as.data.frame(quart1_1)
        part1 <-
          paste(paste0(quart1_1[, 1], " (", as.character(quart1_1[, 2]), ")"),
            collapse = ", "
          )

        quart2_1 <- overview_tab(quart2, !!id, !!time)
        quart2_1 <- as.data.frame(quart2_1)
        part2 <-
          paste(paste0(quart2_1[, 1], " (", as.character(quart2_1[, 2]), ")"),
            collapse = ", "
          )

        quart3_1 <- overview_tab(quart3, !!id, !!time)
        quart3_1 <- as.data.frame(quart3_1)
        part3 <-
          paste(paste0(quart3_1[, 1], " (", as.character(quart3_1[, 2]), ")"),
            collapse = ", "
          )

        quart4_1 <- overview_tab(quart4, !!id, !!time)
        quart4_1 <- as.data.frame(quart4_1)
        part4 <-
          paste(paste0(quart4_1[, 1], " (", as.character(quart4_1[, 2]), ")"),
            collapse = ", "
          )

        # Bring it back in a data frame structure to make it easily
        # convertible to a table
        dat1 <-
          cbind(part1, part2)
        dat2 <- cbind(part3, part4)
        crosstab <-
          data.frame(rbind(dat1, dat2))

        return(crosstab)
      }

      # If this is not the case, we need to aggregate the data
      else {
        red <- dat %>%
          dplyr::ungroup() %>%
          dplyr::group_by(!!id, !!time) %>%
          dplyr::summarise(
            cond1_mean = mean(!!cond1),
            cond2_mean = mean(!!cond2)
          ) %>%
          dplyr::ungroup()

        cond1_mean <- red$cond1_mean
        cond1_mean <- dplyr::enquo(cond1_mean)

        cond2_mean <- red$cond2_mean
        cond2_mean <- dplyr::enquo(cond2_mean)

        # Apply the code to the code above
        red <- red %>%
          dplyr::mutate(
            c1 = ifelse(!!cond1_mean >= threshold1, 1, 0),
            c2 = ifelse(!!cond2_mean >= threshold2, 1, 0)
          ) %>%
          dplyr::group_by(c1, c2) %>%
          dplyr::mutate(
            quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
            quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
            quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
            quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
          ) %>%
          dplyr::ungroup()

        quart1 <-
          red %>%
          dplyr::filter(quart1 == 1) %>%
          dplyr::select(!!id, !!time)
        quart2 <-
          red %>%
          dplyr::filter(quart2 == 1) %>%
          dplyr::select(!!id, !!time)
        quart3 <-
          red %>%
          dplyr::filter(quart3 == 1) %>%
          dplyr::select(!!id, !!time)
        quart4 <-
          red %>%
          dplyr::filter(quart4 == 1) %>%
          dplyr::select(!!id, !!time)

        quart1_1 <- overview_tab(quart1, !!id, !!time)
        quart1_1 <- as.data.frame(quart1_1)
        part1 <-
          paste(paste0(quart1_1[, 1], " (", as.character(quart1_1[, 2]), ")"),
            collapse = ", "
          )

        quart2_1 <- overview_tab(quart2, !!id, !!time)
        quart2_1 <- as.data.frame(quart2_1)
        part2 <-
          paste(paste0(quart2_1[, 1], " (", as.character(quart2_1[, 2]), ")"),
            collapse = ", "
          )

        quart3_1 <- overview_tab(quart3, !!id, !!time)
        quart3_1 <- as.data.frame(quart3_1)
        part3 <-
          paste(paste0(quart3_1[, 1], " (", as.character(quart3_1[, 2]), ")"),
            collapse = ", "
          )

        quart4_1 <- overview_tab(quart4, !!id, !!time)
        quart4_1 <- as.data.frame(quart4_1)
        part4 <-
          paste(paste0(quart4_1[, 1], " (", as.character(quart4_1[, 2]), ")"),
            collapse = ", "
          )

        # Bring it back in a data frame structure to make
        # it easily convertible to a table
        dat1 <- cbind(part1, part2)
        dat2 <- cbind(part3, part4)
        crosstab <- data.frame(rbind(dat1, dat2))

        return(crosstab)
      }
    } else {
      warning(
        "There is a missing value in your id variable. The missing value is automatically deleted."
      )

      dat <- dat %>%
        dplyr::filter(!is.na(!!id))


      # Check the length of unique observations
      # (based on time and id) in the data set
      # We need this for the next check
      length_nodup <- dat %>%
        dplyr::distinct(!!id, !!time, .keep_all = TRUE)

      # Check if data set only has unique observations
      if (nrow(length_nodup) == nrow(dat)) {
        red <- dat %>%
          dplyr::mutate(
            c1 = ifelse(!!cond1 >= threshold1, 1, 0),
            c2 = ifelse(!!cond2 >= threshold2, 1, 0)
          ) %>%
          dplyr::group_by(c1, c2) %>%
          dplyr::select(!!id, !!time, !!cond1, !!cond2, c1, c2) %>%
          dplyr::mutate(
            quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
            quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
            quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
            quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
          ) %>%
          dplyr::ungroup()

        quart1 <-
          red %>%
          dplyr::filter(quart1 == 1) %>%
          dplyr::select(!!id, !!time)
        quart2 <-
          red %>%
          dplyr::filter(quart2 == 1) %>%
          dplyr::select(!!id, !!time)
        quart3 <-
          red %>%
          dplyr::filter(quart3 == 1) %>%
          dplyr::select(!!id, !!time)
        quart4 <-
          red %>%
          dplyr::filter(quart4 == 1) %>%
          dplyr::select(!!id, !!time)

        quart1_1 <- overview_tab(quart1, !!id, !!time)
        quart1_1 <- as.data.frame(quart1_1)
        part1 <-
          paste(paste0(quart1_1[, 1], " (", as.character(quart1_1[, 2]), ")"),
            collapse = ", "
          )

        quart2_1 <- overview_tab(quart2, !!id, !!time)
        quart2_1 <- as.data.frame(quart2_1)
        part2 <-
          paste(paste0(quart2_1[, 1], " (", as.character(quart2_1[, 2]), ")"),
            collapse = ", "
          )

        quart3_1 <- overview_tab(quart3, !!id, !!time)
        quart3_1 <- as.data.frame(quart3_1)
        part3 <-
          paste(paste0(quart3_1[, 1], " (", as.character(quart3_1[, 2]), ")"),
            collapse = ", "
          )

        quart4_1 <- overview_tab(quart4, !!id, !!time)
        quart4_1 <- as.data.frame(quart4_1)
        part4 <-
          paste(paste0(quart4_1[, 1], " (", as.character(quart4_1[, 2]), ")"),
            collapse = ", "
          )

        # Bring it back in a data frame structure to make it easily
        # convertible to a table
        dat1 <-
          cbind(part1, part2)
        dat2 <- cbind(part3, part4)
        crosstab <-
          data.frame(rbind(dat1, dat2))

        return(crosstab)
      }

      # If this is not the case, we need to aggregate the data
      else {
        red <- dat %>%
          dplyr::ungroup() %>%
          dplyr::group_by(!!id, !!time) %>%
          dplyr::summarise(
            cond1_mean = mean(!!cond1),
            cond2_mean = mean(!!cond2)
          ) %>%
          dplyr::ungroup()

        cond1_mean <- red$cond1_mean
        cond1_mean <- dplyr::enquo(cond1_mean)

        cond2_mean <- red$cond2_mean
        cond2_mean <- dplyr::enquo(cond2_mean)

        # Apply the code to the code above
        red <- red %>%
          dplyr::mutate(
            c1 = ifelse(!!cond1_mean >= threshold1, 1, 0),
            c2 = ifelse(!!cond2_mean >= threshold2, 1, 0)
          ) %>%
          dplyr::group_by(c1, c2) %>%
          dplyr::mutate(
            quart1 = ifelse(c1 == 1 & c2 == 1, 1, 0),
            quart2 = ifelse(c1 == 0 & c2 == 1, 1, 0),
            quart3 = ifelse(c1 == 1 & c2 == 0, 1, 0),
            quart4 = ifelse(c1 == 0 & c2 == 0, 1, 0)
          ) %>%
          dplyr::ungroup()

        quart1 <-
          red %>%
          dplyr::filter(quart1 == 1) %>%
          dplyr::select(!!id, !!time)
        quart2 <-
          red %>%
          dplyr::filter(quart2 == 1) %>%
          dplyr::select(!!id, !!time)
        quart3 <-
          red %>%
          dplyr::filter(quart3 == 1) %>%
          dplyr::select(!!id, !!time)
        quart4 <-
          red %>%
          dplyr::filter(quart4 == 1) %>%
          dplyr::select(!!id, !!time)

        quart1_1 <- overview_tab(quart1, !!id, !!time)
        quart1_1 <- as.data.frame(quart1_1)
        part1 <-
          paste(paste0(quart1_1[, 1], " (", as.character(quart1_1[, 2]), ")"),
            collapse = ", "
          )

        quart2_1 <- overview_tab(quart2, !!id, !!time)
        quart2_1 <- as.data.frame(quart2_1)
        part2 <-
          paste(paste0(quart2_1[, 1], " (", as.character(quart2_1[, 2]), ")"),
            collapse = ", "
          )

        quart3_1 <- overview_tab(quart3, !!id, !!time)
        quart3_1 <- as.data.frame(quart3_1)
        part3 <-
          paste(paste0(quart3_1[, 1], " (", as.character(quart3_1[, 2]), ")"),
            collapse = ", "
          )

        quart4_1 <- overview_tab(quart4, !!id, !!time)
        quart4_1 <- as.data.frame(quart4_1)
        part4 <-
          paste(paste0(quart4_1[, 1], " (", as.character(quart4_1[, 2]), ")"),
            collapse = ", "
          )

        # Bring it back in a data frame structure to make
        # it easily convertible to a table
        dat1 <- cbind(part1, part2)
        dat2 <- cbind(part3, part4)
        crosstab <- data.frame(rbind(dat1, dat2))

        return(crosstab)
      }
    }
  }

#' @title calculate_share_row_wise
#'
#' @description Function used in `overview_na` to calculate the share of NA row-wise
#'
#' @param dat Data frame
#' @return The function returns a data set that has the information
#'     on the row-wise NA share

calculate_share_row_wise <- function(dat = NULL) {
  if (any(class(dat) == "data.table")) {
    dat <- data.table::copy(dat)
    dat_result <-
      dat[, list(na_count = rowSums(is.na(dat)), total = ncol(dat))][, .(na_count, total)]

    # Add rownames as variable and get the percentage
    dat_result <-
      dat_result[, list(
        na_count = 1:nrow(dat_result),
        percentage = na_count / (total / 100)
      )]
  } else {
    apply(dat, MARGIN = 1, function(x) {
      sum(is.na(x))
    })

    dat_result <- dat %>%
      dplyr::rowwise() %>%
      dplyr::summarise(dplyr::across(dplyr::everything(), list(~ sum(is.na(
        .
      ))))) %>%
      dplyr::mutate(
        na_count = rowSums(.),
        total = length(colnames(.))
      ) %>%
      dplyr::select(na_count, total)

    # Add rownames as variable
    dat_result$variable <- 1:nrow(dat_result)

    # Get percentage
    dat_result <- dat_result %>%
      dplyr::mutate(percentage = na_count / (total / 100))
  }
  return(dat_result)
}

#' @title overview_plot_absolute
#'
#' @description Function used in `overview_na` to plot the absolute share of NA values
#'
#' @param dat_result Data frame
#' @param theme_plot Theme for the plot (pre-defined)
#' @param yaxis Name for yaxis
#' @param xaxis Name for xaxix
#' @return The function returns a ggplot
#'
overview_plot_absolute <-
  function(dat_result = NULL,
           theme_plot = NULL,
           yaxis = NULL,
           xaxis = NULL) {
    plot <- ggplot2::ggplot(data = dat_result) +
      ggplot2::geom_col(ggplot2::aes(
        y = reorder(variable, -na_count),
        x = na_count
      )) +
      ggplot2::ylab(yaxis) +
      ggplot2::xlab(xaxis) +
      theme_plot
    return(plot)
  }

#' @title overview_tab
#'
#' @description Provides an overview table for the time and scope conditions of
#'     a data set. If a data.table object is provided, the function uses
#'     data.table's syntax to perform the evaluation
#'
#' @param dat A data frame or data table object
#' @param id Scope (e.g., country codes or individual IDs)
#' @param time Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).
#' @param complex_date Boolean argument identifying if there is a more complex (list-wise) date_time parameter (FALSE is the default)
#' @return A data frame object that contains a summary of a sample that
#'     can later be converted to a 'LaTeX' output using \code{overview_latex}
#' @examples
#' # With version 1 (and also 2):
#'
#' data(toydata)
#' output_table <- overview_tab(dat = toydata, id = ccode, time = year)
#'
#' # With version 3:
#' overview_tab(dat = toydata, id = ccode, time = list(
#'   year = toydata$year,
#'   month = toydata$month, day = toydata$day
#' ), complex_date = TRUE)
#'
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom rlang :=


overview_tab <- function(dat,
                         id,
                         time = list(year = NULL, month = NULL, day = NULL),
                         complex_date = FALSE) {


  # Check whether time contains multiple objects
  if (complex_date) {
    # Identify non-empty objects
    time <- time[lapply(time, length) > 0]

    if (is.null(time$day)) {
      stop(
        "The current version requires a day if you are providing multiple time arguments. Please also add a `day` in `time = list(year = ..., month = ..., day = ...)`."
      )
    }
    # If month object is a character, convert it into numbers
    if (!is.null(time$month) & !is.numeric(time$month)) {
      date <- paste(time$year, time$month, time$day, sep = "-")

      # if (any(grepl("-$", date))) {
      #   date <- gsub("-$", replacement = "", date)
      # } else if (any(grepl("--$", date))) {
      #   date <- gsub("--$", replacement = "", date)
      # }

      # Convert a possible non-numeric month to a numeric month
      if (!is.null(time$year) &
        !is.null(time$month) & !is.null(time$day)) {
        dat$date_time <-
          as.Date(strftime(as.POSIXlt(date, format = "%Y-%b-%d")))
      }
    }
  }

  if (any(class(dat) == "data.table")) {
    # Start with the data
    if (!complex_date) {
      time <- deparse(substitute(time))
    } else {
      time <- deparse(substitute(date_time))
    }
    id <- deparse(substitute(id))
    col_names <- c(id, time)

    # Check if there are NAs in the time or id variable
    # (and drop them but warn the user about it)
    if (sum(is.na(dat[[id]])) > 0) {
      warning(
        "There is a missing value in your id variable. The missing value is automatically deleted."
      )
      dat <- dat[!is.na(get(id)), col_names, with = FALSE]
    }

    output <- overview_tab_dt(
      dat = dat,
      id = id,
      time = time,
      col_names = col_names
    )
  } else {
    # Start with the data
    if (!complex_date) {
      time <- rlang::ensym(time)
    } else {
      time <- "date_time"
      time <- rlang::ensym(time)
    }
    id <- rlang::ensym(id)


    # Check if there are NAs in the time or id variable
    # (and drop them but warn the user about it)
    dat2 <- dat %>%
      dplyr::filter(!is.na(!!id))

    if (nrow(dat2) != nrow(dat)) {
      warning(
        "There is a missing value in your id variable. The missing value is automatically deleted."
      )
    }

    output <- overview_tab_df(
      dat2 = dat2,
      dat = dat,
      id = id,
      time = time
    )
  }
  return(output)
}

test_that("overview_tab() returns same results regardless of using
          data.table or data.frame", {
  output_table <- overview_tab(dat = toydata, id = ccode, time = year)
  toydata_copy <- data.table::copy(toydata)
  toydata_dt <- data.table::setDT(toydata_copy)
  output_table2 <-
    overview_tab(dat = toydata_dt, id = ccode, time = year)
  expect_equal(nrow(output_table2), nrow(output_table))
})

test_that("overview_tab() returns same results regardless of using
          data.table or data.frame", {
  toydata_no_dup <-
    toydata %>%
    dplyr::select(ccode, year) %>%
    dplyr::group_by(ccode, year) %>%
    dplyr::distinct()
  output_table <-
    overview_tab(dat = toydata_no_dup, id = ccode, time = year)
  toydata_no_dup_copy <- data.table::copy(toydata_no_dup)
  toydata_dt <- data.table::setDT(toydata_no_dup_copy)
  output_table2 <-
    overview_tab(dat = toydata_dt, id = ccode, time = year)
  expect_equal(nrow(output_table2), nrow(output_table))
})

test_that("overview_na() returns same results regardless of using data.table
          or data.frame", {
  output <- overview_na(dat = toydata)
  toydata_copy <- data.table::copy(toydata)
  toydata_dt <- data.table::setDT(toydata_copy)
  output2 <- overview_na(dat = toydata_dt)
  testthat::expect_is(output2, "ggplot")
  testthat::expect_is(output, "ggplot")
})

test_that(
  "overview_na() returns same results regardless of using data.table
          or data.frame (row_wise=TRUE)",
  {
    output <- overview_na(dat = toydata, row_wise = TRUE)
    toydata_copy <- data.table::copy(toydata)
    toydata_dt <- data.table::setDT(toydata_copy)
    output2 <-
      overview_na(dat = toydata_dt, row_wise = TRUE)
    testthat::expect_is(output2, "ggplot")
    testthat::expect_is(output, "ggplot")
  }
)

test_that(
  "overview_na() returns same results regardless of using data.table
          or data.frame (add=TRUE)",
  {
    output <- overview_na(dat = toydata, row_wise = TRUE, add = TRUE)
    toydata_copy <- data.table::copy(toydata)
    toydata_dt <- data.table::setDT(toydata_copy)
    output2 <-
      overview_na(dat = toydata_dt, row_wise = TRUE, add = TRUE)
    testthat::expect_is(output2, "data.frame")
    testthat::expect_is(output, "data.frame")
  }
)

test_that("check output of overview_heat with dt", {
  toydata_copy <- data.table::copy(toydata)
  toydata_dt <- data.table::setDT(toydata_copy)

  plot_heat <-
    overview_heat(toydata_dt,
      ccode,
      year,
      perc = TRUE,
      exp_total = 12
    )
  testthat::expect_is(plot_heat, "ggplot")
  plot_heat_abs <-
    overview_heat(toydata_dt, ccode, year, perc = FALSE)
  testthat::expect_is(plot_heat_abs, "ggplot")
})

test_that("for complex_date in overview_tab", {
  toydata_copy <- data.table::copy(toydata)
  toydata_dt <- data.table::setDT(toydata_copy)

  output_table <-
    overview_tab(
      dat = toydata,
      id = ccode,
      time = list(
        year = toydata$year,
        month = toydata$month,
        day = toydata$day
      ),
      complex_date = TRUE
    )
  output_table2 <-
    overview_tab(
      dat = toydata_dt,
      id = ccode,
      time = list(
        year = toydata_dt$year,
        month = toydata_dt$month,
        day = toydata_dt$day
      ),
      complex_date = TRUE
    )
  expect_equal(nrow(output_table2), nrow(output_table))
})


test_that("Get a warning message from overview_tab", {
  data_test <- toydata %>%
    dplyr::mutate(ccode = ifelse(ccode == "RWA", NA, ccode))

  toydata_copy <- data.table::copy(data_test)
  toydata_dt <- data.table::setDT(toydata_copy)

  expect_warning(
    overview_tab(dat = toydata_dt, id = ccode, time = year)
  )
})

#' Cross-sectional data for countries
#'
#' Small, artificially generated toy data set that comes in a cross-sectional
#' format where the unit of analysis is either country-year or
#' country-year-month. It provides artificial information for five countries
#' (Angola, Benin, France, Rwanda, and the UK) for a time span from 1990 to
#' 1999 to illustrate the use of the package.
#'
#' @docType data
#'
#' @usage data(toydata)
#'
#' @format An object of class \code{"data.frame"}
#' \describe{
#'  \item{ccode}{ISO3 country code (as character) for the countries in the
#'      sample (Angola, Benin, France, Rwanda, and UK)}
#'  \item{year}{A value between 1990 and 1999}
#'  \item{month}{An abbreviation (MMM) for month (character)}
#'  \item{gpd}{A fake value for GDP (randomly generated)}
#'  \item{population}{A fake value for population (randomly generated)}
#' }
#' @references This data set was artificially created for the overviewR package.
#' @keywords datasets
#' @examples
#'
#' data(toydata)
#' head(toydata)
"toydata"

#' @title overview_tab_dt
#'
#' @description Internal function that calculates the `overview_tab` for data.table objects
#'
#' @param dat Your data set
#' @param id Scope (e.g., country codes or individual IDs)
#' @param time Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).
#' @param col_names The column names (containing id and time)
#' @return A data.table

overview_tab_dt <- function(dat = NULL,
                            id = NULL,
                            time = NULL,
                            col_names = NULL) {

  # Check if data set only has unique observations
  if (nrow(unique(dat, by = c(id, time))) == nrow(dat)) {
    tab <- .overview_tab(
      dat = dat,
      id = id,
      time = time,
      col_names = col_names
    )

    # Return object
    return(tab)
  }
  # If this is not the case, we need to aggregate the data
  else {
    dat <- unique(dat[, ..col_names])

    # Apply code from above to the new data
    # Apply it to the data
    tab <- .overview_tab(
      dat = dat,
      id = id,
      time = time,
      col_names = col_names
    )

    return(tab)
  }
}

utils::globalVariables(
  c(
    "c1",
    "c2",
    "time_frame",
    "toydata",
    "count",
    "value",
    "count2",
    "grp",
    "n",
    "percentage",
    "total",
    "variable",
    "idx",
    "text",
    "quart4",
    "quart3",
    "quart2",
    "quart1",
    ".",
    "na_count",
    "..col_names",
    "..return_cols"
  )
)

#' @title theme_heat_plot
#'
#' @description Defines the theme for the `overview_heat` plot function
#'
#' @return A theme for the `overview_heat` plot
#'

theme_heat_plot <- function() {
  theme_plot <- ggplot2::theme(
    # get rid of panel grids
    axis.line = ggplot2::element_blank(),
    axis.ticks = ggplot2::element_blank(),
    panel.border = ggplot2::element_blank(),
    panel.grid.major = ggplot2::element_blank(),
    panel.grid.minor = ggplot2::element_blank(),
    # Change plot and panel background
    plot.background = ggplot2::element_rect(fill = "white"),
    panel.background = ggplot2::element_rect(fill = "white"),
    # Change legend
    legend.direction = "horizontal",
    legend.position = "none",
    legend.background = ggplot2::element_rect(fill = "black", color = NA),
    legend.key = ggplot2::element_rect(color = "black", fill = "black"),
    legend.title = ggplot2::element_blank(),
    # Change text
    plot.caption = ggplot2::element_text(size = 5),
    axis.text = ggplot2::element_text(
      face = "plain",
      color = "black",
      size = 8
    ),
    text = ggplot2::element_text(
      size = 8,
      face = "plain"
    )
  )

  return(theme_plot)
}

#' @title overview_na
#'
#' @description This function plots a ggplot to visualize the distribution of
#'     NAs across all variables in the data set.
#'
#' @param dat Your data set
#' @param yaxis Label of your y axis ("Variables" is default)
#' @param perc If TRUE (default) plot returns the number of NAs in percentage
#' @param row_wise If TRUE (FALSE is default) plot return the number of NAs
#'     per row
#' @param add If TRUE (FALSE is default) it generates a new data frame with
#'     na_count and percentage share of NAs for each row
#' @return Depending on the selection, the function returns a ggplot figure that
#'     presents the distribution of NAs in the data set or adds the information
#'     on the row-wise NA share
#' @examples
#' data(toydata)
#' overview_na(toydata, perc = FALSE)
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom tibble "rownames_to_column"
#' @importFrom ggplot2 ggplot
#' @importFrom stats reorder
#' @importFrom data.table data.table

overview_na <- function(dat,
                        yaxis = "Variables",
                        perc = TRUE,
                        row_wise = FALSE,
                        add = FALSE) {
  # Set theme ---------------------------------------------------------------
  # Create a theme for the plot
  theme_plot <- theme_na_plot()

  # Check for missing values in month/day columns ---------------------------
  # Warn users when typical time-unit columns (month, day) contain NAs,
  # since gaps in these columns can silently distort time-coverage analyses.
  time_cols <- intersect(tolower(names(dat)), c("month", "day"))
  if (length(time_cols) > 0 && !row_wise) {
    na_time <- vapply(time_cols, function(col) {
      any(is.na(dat[[col]]))
    }, logical(1))
    if (any(na_time)) {
      affected <- paste(
        names(dat)[tolower(names(dat)) %in% time_cols[na_time]],
        collapse = ", "
      )
      warning(
        "Missing values detected in time-related column(s): ",
        affected,
        ". Consider using `row_wise = TRUE` or inspecting these columns ",
        "before drawing conclusions about time coverage."
      )
    }
  }

  # Perform calculations ----------------------------------------------------

  if(row_wise) {
    yaxis <- "Observations"
  }

  # Start with the data
  dat <- dat

  if (row_wise == FALSE) {
    # Calculate the share non_row_wise
    dat_result <- calculate_share_non_row_wise(dat = dat)

    # Percentage --------------------------------------------------------------
    if (perc == TRUE) {
      plot_perc <-
        overview_plot_percentage(
          dat_result = dat_result,
          theme_plot = theme_plot,
          yaxis = yaxis,
          xaxis = "Number of NA (in %)"
        )

      return(plot_perc)
    } else if (perc == FALSE) {
      # Absolute numbers --------------------------------------------------------
      plot_absolute <-
        overview_plot_absolute(
          dat_result = dat_result,
          theme_plot = theme_plot,
          yaxis = yaxis,
          xaxis = "Number of NA (total)"
        )

      return(plot_absolute)
    }
  }

  if (row_wise == TRUE) {
    # Calculate the share row_wise
    dat_result <- calculate_share_row_wise(dat = dat)

    # Absolute numbers --------------------------------------------------------
    if (add == FALSE && perc == FALSE) {
      plot_absolute <- overview_plot_absolute(
        dat_result = dat_result,
        theme_plot = theme_plot,
        yaxis = yaxis,
        xaxis = "Number of NA (total)"
      )

      return(plot_absolute)
    }

    # Percentage --------------------------------------------------------------
    if (add == FALSE && perc == TRUE) {
      plot_perc <- overview_plot_percentage(
        dat_result = dat_result,
        theme_plot = theme_plot,
        yaxis = yaxis,
        xaxis = "Number of NA (in %)"
      )
      return(plot_perc)
    }

    if (add == TRUE) {
      dat_with_na <-
        overview_add_na_output(dat_result = dat_result, dat = dat)
      return(dat_with_na)
    }
  }
}

#' @title overview_heat
#'
#' @description This function plots a heat map to visualize the
#'     coverage of the time-scope-units of the data. Options include total
#'     number of cases per time-scope-unit or relative number in percentage.
#' @param dat The data set
#' @param id The scope (e.g., country codes or individual IDs). The axis is
#'     ordered in ascending order by default.
#' @param time The time (e.g., time periods given by years, months, ...)
#' @param perc If FALSE (default) plot returns the total number of observations
#'     per time-scope-unit. If TRUE, it returns the number of observations per
#'     time-scope-unit in percentage
#' @param exp_total Expected total number of observations (i.e. maximum)
#'     for time unit.
#' @param xaxis Label of your x axis ("Time frame" is default)
#' @param yaxis Label of your y axis ("Sample" is default)
#' @param col_low Hex color code for the lowest value (default is "#dceaf2")
#' @param col_high Hex color code for the lowest value (default is "#2A5773")
#' @param label If TRUE (default), the total number of observations/percentages
#'     of observations are displayed. If FALSE, it returns no labels.
#' @return A ggplot figure that presents sample coverage visually
#' @examples
#' data(toydata)
#' overview_heat(toydata, ccode, year, perc = TRUE, exp_total = 12)
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom ggplot2 ggplot

overview_heat <-
  function(dat,
           id,
           time,
           perc = FALSE,
           exp_total = NULL,
           xaxis = "Time frame",
           yaxis = "Sample",
           col_low = "#dceaf2",
           col_high = "#2A5773",
           label = TRUE) {

    # Set theme ---------------------------------------------------------------
    theme_plot <- theme_heat_plot()

    # Start with the data
    dat <- dat

    if (any(class(dat) == "data.table")) {
      id <- deparse(substitute(id))
      time <- deparse(substitute(time))
      col_names <- c(id, time)
    } else {
      id <- dplyr::enquo(id)
      time <- dplyr::enquo(time)
    }

    # Plot
    plot <-
      .overview_heat(
        dat = dat,
        id = id,
        time = time,
        label = label,
        perc = perc,
        col_low = col_low,
        col_high = col_high,
        xaxis = xaxis,
        yaxis = yaxis,
        theme_plot = theme_plot,
        exp_total = exp_total,
        col_names = col_names
      )

    return(plot)
  }

#' @title overview_plot
#'
#' @description This function plots a ggplot to visualize the distribution of
#'     scope objects across the time frame.
#'
#' @param dat Your data set
#' @param id Your scope (e.g., country codes or individual IDs). If the id
#'     variable contains NAs, they will not be included in the plot.
#' @param time Your time (e.g., time periods given by years, months, ...)
#' @param xaxis Label of the x axis ("Time frame" is default)
#' @param yaxis Label of the y axis ("Sample" is default)
#' @param asc Sorting the y axis in ascending order ("TRUE" is default)
#' @param color Optional argument. Either a column variable (for conditional
#'     coloring) or a color string (e.g., \code{"steelblue"}) to paint all
#'     lines/points a fixed color. When \code{color} is a column variable the
#'     returned ggplot object can be extended with
#'     \code{+ ggplot2::scale_color_manual()} or
#'     \code{+ ggplot2::scale_color_brewer()} to apply custom palettes.
#' @param dot_size Option argument that defines the dot size (default is 2)
#' @return A ggplot figure that presents the sample information visually
#' @examples
#' data(toydata)
#' overview_plot(dat = toydata, id = ccode, time = year)
#' @export
#' @importFrom dplyr "%>%"
#' @importFrom ggplot2 ggplot
#' @importFrom rlang enexpr

overview_plot <-
  function(dat,
           id,
           time,
           xaxis = "Time frame",
           yaxis = "Sample",
           asc = TRUE,
           color,
           dot_size = 2) {
    # Create a theme for the plot
    theme_plot <- ggplot2::theme(
      # get rid of panel grids
      axis.line = ggplot2::element_blank(),
      axis.ticks.y = ggplot2::element_blank(),
      axis.ticks.x = ggplot2::element_blank(),
      panel.border = ggplot2::element_blank(),
      panel.grid.major.x = ggplot2::element_line(
        color = "grey90",
        linetype = "dashed"
      ),
      # Change plot and panel background
      plot.background = ggplot2::element_rect(fill = "white"),
      panel.background = ggplot2::element_rect(fill = "white"),
      # Change legend
      legend.direction = "horizontal",
      legend.position = "bottom",
      legend.background = ggplot2::element_rect(fill = "white", color = NA),
      legend.key = ggplot2::element_rect(color = "white", fill = "white"),
      legend.title = ggplot2::element_blank(),
      # Change text
      plot.caption = ggplot2::element_text(size = 5),
      axis.text = ggplot2::element_text(
        face = "plain",
        color = "black",
        size = 8
      ),
      text = ggplot2::element_text(
        size = 10,
        face = "plain"
      )
    )

    # First: Evaluate whether we have a color argument given or not
    if (missing(color) == TRUE) {
      # Start with the data
      dat <- dat
      id <- dplyr::enquo(id)
      time <- dplyr::enquo(time)

      # Reduce data frame to distinct values and drop if observations with NA
      # in the time variable and id variable
      # We further ungroup any grouping before continuing
      dat_red <- dat %>%
        dplyr::ungroup() %>%
        dplyr::distinct(!!id, !!time) %>%
        dplyr::filter(!is.na(!!id)) %>%
        dplyr::filter(!is.na(!!time)) %>%
        dplyr::arrange(!!id, !!time)
      # The following code is inspired by: https://bit.ly/2CpS3B7
      dat_red <- dat_red
      dat_red <- dat_red %>%
        dplyr::mutate(idx = c(1, diff(!!time)))
      i2 <- c(1, which(dat_red$idx != 1), nrow(dat_red) + 1)
      dat_red$grp <- rep(seq_len(length(diff(i2))), diff(i2))

      # Adjust the plot where needed (trailing NA and leading NAs for instance)
      dat_red <-
        dat_red %>% dplyr::mutate(
          grp = ifelse(dplyr::lead(!!id) !=
            !!id &
            dplyr::lead(idx) == 1, idx + 1, grp),
          grp = ifelse(
            is.na(grp) &
              dplyr::lag(!!id) == !!id & idx == 1,
            dplyr::lag(grp),
            grp
          ),
          grp = ifelse(
            is.na(grp) &
              !!id == dplyr::lead(!!id),
            dplyr::lag(grp),
            grp
          )
        )

      dat_red <- dat_red

      # Plot it
      if (asc == TRUE) {
        plot <- dat_red %>%
          dplyr::group_by(!!id) %>%
          ggplot2::ggplot(ggplot2::aes(x = factor(!!time), y = !!id)) +
          ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp)) +
          ggplot2::geom_point(pch = 15, size = dot_size) +
          # ggplot2::scale_color_manual(factor(!!color)) +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          ggplot2::scale_y_discrete(limits = rev) +
          theme_plot

        return(plot)
      } else {
        plot <- dat_red %>%
          dplyr::group_by(!!id) %>%
          ggplot2::ggplot(ggplot2::aes(x = factor(!!time), y = !!id)) +
          ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp)) +
          ggplot2::geom_point(pch = 15, size = 2) +
          # ggplot2::scale_color_manual() +
          ggplot2::ylab(yaxis) +
          ggplot2::xlab(xaxis) +
          theme_plot

        return(plot)
      }
    } else {
      # Detect whether color is a literal string (e.g. "steelblue") or a
      # column reference (e.g. `before`).
      color_expr <- rlang::enexpr(color)
      color_is_string <- is.character(color_expr)

      # Start with the data
      dat <- dat
      id <- dplyr::enquo(id)
      time <- dplyr::enquo(time)

      if (color_is_string) {
        fixed_color <- as.character(color_expr)

        dat_red <- dat %>%
          dplyr::ungroup() %>%
          dplyr::distinct(!!id, !!time) %>%
          dplyr::filter(!is.na(!!id)) %>%
          dplyr::filter(!is.na(!!time)) %>%
          dplyr::arrange(!!id, !!time)
        dat_red <- dat_red %>%
          dplyr::mutate(idx = c(1, diff(!!time)))
        i2 <- c(1, which(dat_red$idx != 1), nrow(dat_red) + 1)
        dat_red$grp <- rep(seq_len(length(diff(i2))), diff(i2))

        dat_red <-
          dat_red %>% dplyr::mutate(
            grp = ifelse(dplyr::lead(!!id) !=
              !!id &
              dplyr::lead(idx) == 1, idx + 1, grp),
            grp = ifelse(
              is.na(grp) &
                dplyr::lag(!!id) == !!id & idx == 1,
              dplyr::lag(grp),
              grp
            ),
            grp = ifelse(
              is.na(grp) &
                !!id == dplyr::lead(!!id),
              dplyr::lag(grp),
              grp
            )
          )

        if (asc == TRUE) {
          plot <- dat_red %>%
            dplyr::group_by(!!id) %>%
            ggplot2::ggplot(ggplot2::aes(x = factor(!!time), y = !!id)) +
            ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp),
                               color = fixed_color) +
            ggplot2::geom_point(pch = 15, size = dot_size,
                                color = fixed_color) +
            ggplot2::ylab(yaxis) +
            ggplot2::xlab(xaxis) +
            ggplot2::scale_y_discrete(limits = rev) +
            theme_plot
          return(plot)
        } else {
          plot <- dat_red %>%
            dplyr::group_by(!!id) %>%
            ggplot2::ggplot(ggplot2::aes(x = factor(!!time), y = !!id)) +
            ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp),
                               color = fixed_color) +
            ggplot2::geom_point(pch = 15, size = dot_size,
                                color = fixed_color) +
            ggplot2::ylab(yaxis) +
            ggplot2::xlab(xaxis) +
            theme_plot
          return(plot)
        }
      } else {
        color <- dplyr::enquo(color)

        # Reduce data frame to distinct values and drop if observations with NA
        # in the time variable and id variable
        # We further ungroup any grouping before continuing
        dat_red <- dat %>%
          dplyr::ungroup() %>%
          dplyr::distinct(!!id, !!time, !!color) %>%
          dplyr::filter(!is.na(!!id)) %>%
          dplyr::filter(!is.na(!!time)) %>%
          dplyr::arrange(!!id, !!time, !!color)
        # The following code is inspired by: https://bit.ly/2CpS3B7
        dat_red <- dat_red %>%
          dplyr::mutate(idx = c(1, diff(!!time)))
        i2 <- c(1, which(dat_red$idx != 1), nrow(dat_red) + 1)
        dat_red$grp <- rep(seq_len(length(diff(i2))), diff(i2))

        # Adjust the plot where needed (trailing NA and leading NAs for instance)
        dat_red <-
          dat_red %>% dplyr::mutate(
            grp = ifelse(dplyr::lead(!!id) !=
              !!id &
              dplyr::lead(idx) == 1, idx + 1, grp),
            grp = ifelse(
              is.na(grp) &
                dplyr::lag(!!id) == !!id & idx == 1,
              dplyr::lag(grp),
              grp
            ),
            grp = ifelse(
              is.na(grp) &
                !!id == dplyr::lead(!!id),
              dplyr::lag(grp),
              grp
            )
          )

        # Plot it
        if (asc == TRUE) {
          plot <- dat_red %>%
            dplyr::group_by(!!id) %>%
            ggplot2::ggplot(ggplot2::aes(
              x = factor(!!time),
              y = !!id,
              col = factor(!!color)
            )) +
            ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp)) +
            ggplot2::geom_point(pch = 15, size = dot_size) +
            ggplot2::ylab(yaxis) +
            ggplot2::xlab(xaxis) +
            ggplot2::scale_y_discrete(limits = rev) +
            theme_plot

          return(plot)
        } else {
          plot <- dat_red %>%
            dplyr::group_by(!!id) %>%
            ggplot2::ggplot(ggplot2::aes(
              x = factor(!!time),
              y = !!id,
              col = factor(!!color)
            )) +
            ggplot2::geom_line(size = 1.5, ggplot2::aes(group = grp)) +
            ggplot2::geom_point(pch = 15, size = 2) +
            ggplot2::ylab(yaxis) +
            ggplot2::xlab(xaxis) +
            theme_plot

          return(plot)
        }
      }
    }
  }

#' @title calculate_share_non_row_wise
#'
#' @description Function used in `overview_na` to calculate the column-wise share of NA
#'
#' @param dat Data frame
#' @return The function returns a data set that has the information
#'     on the column-wise NA share
#'
calculate_share_non_row_wise <- function(dat = NULL) {
  if (any(class(dat) == "data.table")) {
    # Generate necessary variables --------------------------------------------
    na_count <- vapply(dat, function(y) {
      sum(length(which(is.na(
        y
      ))))
    }, FUN.VALUE = numeric(1))
    total <- vapply(dat, function(y) {
      length(y)
    }, FUN.VALUE = numeric(1))

    dat_result <- data.table(na_count, total)

    # Add rownames as variable
    dat_result <-
      data.table::setDT(dat_result, keep.rownames = "variable")[]

    # Get percentage
    dat_result <- dat_result[, list(percentage = na_count / (total / 100))]
  } else {
    # Generate necessary variables --------------------------------------------
    na_count <- vapply(dat, function(y) {
      sum(length(which(is.na(
        y
      ))))
    }, FUN.VALUE = numeric(1))
    total <- vapply(dat, function(y) {
      length(y)
    }, FUN.VALUE = numeric(1))

    dat_result <- data.frame(na_count, total)
    # Add rownames as variable
    dat_result <-
      tibble::rownames_to_column(dat_result, var = "variable")
    # Get percentage
    dat_result <- dat_result %>%
      dplyr::mutate(percentage = na_count / (total / 100))
  }
  return(dat_result)
}

---
title: "overviewR: Easily Extracting Information About Your Data"
author: "Cosima Meyer and Dennis Hammerschmidt"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{overviewR: Easily Extracting Information About Your Data}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(collapse = TRUE,
                      comment = "#>")
options(repos = c(CRAN = "[https://cloud.r-project.org](https://cloud.r-project.org)"))
```


```{R,echo=FALSE,results='hide',message=FALSE,include=FALSE, eval=TRUE}
if (!require(knitr))
  install.packages("knitr")
if (!require(devtools))
  install.packages("devtools")
if (!require(dplyr))
  install.packages("dplyr")
if (!require(magrittr))
  install.packages("magrittr")
if (!require(ggplot2))
  install.packages("ggplot2")
if (!require(countrycode))
  install.packages("countrycode")
if (!require(xtable))
  install.packages("xtable")
```


The goal of overviewR is to make it easy to get an overview of a data set by displaying relevant sample information. At the moment, there are the following functions:

- `overview_tab` generates a tabular overview of the sample.  The general sample plots a two-column table that provides information on an id in the left column and a the time frame on the right column.
- `overview_crosstab` generates a cross table. The conditional column allows to disaggregate the overview table by specifying two conditions, hence resulting a 2x2 table. This way, it is easy to visualize the time and scope conditions as well as theoretical assumptions with examples from the data set.
- `overview_latex` converts the output of both `overview_tab` and `overview_crosstab` into LaTeX code and/or directly into a .tex file.
- `overview_markdown` converts the output of both `overview_tab` and `overview_crosstab` into Markdown and/or directly into a .md file.
- `overview_plot` is an alternative to visualize the sample (a way to present results from `overview_tab`)
- `overview_crossplot` is an alternative to visualize a cross table (a way to present results from `overview_crosstab`)
- `overview_heat` plots a heat map of your time line
- `overview_na` plots an overview of missing values by variable (column-wise and row-wise)

The plots can be saved using the `ggsave()` command. The output of `overview_tab` and `overview_crosstab` are also compatible with other packages such as [```xtable```](https://CRAN.R-project.org/package=xtable), [```flextable```](https://CRAN.R-project.org/package=flextable), or [`knitr`](https://yihui.org/rmarkdown-cookbook/kable.html).

We present a short step-by-step guide as well as the functions in more detail below.

## Installation

A stable version of `overviewR` can be directly accessed on CRAN:
```{r, eval=FALSE}
install.packages("overviewR", force = TRUE)
```

To install the latest development version of `overviewR` directly from [GitHub](https://github.com/cosimameyer/overviewR) use: 

```{r, message=FALSE, warning=FALSE, results = "hide", eval=FALSE}
library(devtools)
devtools::install_github("cosimameyer/overviewR")
```


# Tabular overview
## `overview_tab`

First, load the package.
```{r, include = FALSE, eval = FALSE}
install.packages("overviewR")
```

```{r, message=FALSE, warning=FALSE}
library(overviewR)
```

The following examples use a toy data set (`toydata`) that comes with the package. This data contains artificially generated information in a cross-sectional format on 5 countries, covering the period 1990-1999.

```{r}
data(toydata)
head(toydata)
```
<!-- ``` -->
<!--     ccode   year   month  gdp       population -->
<!--     RWA     1990   Jan    24180.77  14969.988 -->
<!--     RWA     1990   Feb    23650.53  11791.464 -->
<!--     RWA     1990   Mar    21860.14  30047.979 -->
<!--     RWA     1990   Apr    20801.06  19853.556 -->
<!--     RWA     1990   May    18702.84   5148.118 -->
<!--     RWA     1990   Jun    30272.37  48625.140 -->
<!-- ``` -->

There are 264 observations for 5 countries (Angola, Benin, France, Rwanda, and UK) stored in the ```ccode``` variable, over a time period between 1990 to 1999 (```year```) with additional information for the month (```month```). Additionally, two artificially generated fake variables for GDP (```gdp```) and  population size (```population```) are included to illustrate of conditions.

The following functions work best on data sets that have an id-time-structure, in the case of `toydata` this corresponds to country-year with `ccode` and `year`. 
If the data set does not have this format yet, consider using [```pivot_wider()``` or ```pivot_longer()```](https://tidyr.tidyverse.org/reference/pivot_longer.html) to get to the format.

Generate some general overview of the data set using the time and scope conditions with ```overview_tab```.

```{r, message=FALSE, warning=FALSE, eval=FALSE}
output_table <- overview_tab(dat = toydata, id = ccode, time = year)
```

The resulting data frame collapses the time condition for each id by taking into account potential gaps in the time frame. Note that the column name for the time frame is set by default to `time_frame` and internally generated when using `overview_tab`. 

```{r, message=FALSE, eval=FALSE}
output_table
```

```
# ccode   time_frame
# RWA	    1990 - 1995
# AGO	    1990 - 1992
# BEN	    1995 - 1999
# GBR	    1991, 1993, 1995, 1997, 1999
# FRA	    1993, 1996, 1999
```

### Multiple time arguments

As of overviewR version 0.0.7 you can also use multiple time objects in `overview_tab`. You can now pass a list containing multiple time variables with the following format: `time = list(year = NULL, month = NULL, day = NULL)`.

```{r, message=FALSE, eval=FALSE}
output_table_complex <- overview_tab(dat = toydata, id = ccode, 
                                     time = list(year = toydata$year,
                                                 month = toydata$month, 
                                                 day = toydata$day), 
                                     complex_date = TRUE)
```

The resulting data frame collapses again the time condition for each id by taking into account potential gaps in the time frame. Note that the column name for the time frame is set by default to `time_frame` and internally generated when using `overview_tab`. The output resembles something like this:

```{r, message=FALSE, eval=FALSE}
output_table_complex
```

```
 ccode time_frame                                                                                                      # AGO   1990-01-01, 1990-02-02, 1990-03-03, 1990-04-04, 1990-05-05, 1990-06-06, ...
# BEN   1995-01-01, 1995-02-02, 1995-03-03, 1995-04-04, 1995-05-05, 1995-06-06, ...
# FRA   1993-01-01, 1993-02-02, 1993-03-03, 1993-04-04, 1993-05-05, 1993-06-06, ...
# GBR   1991-01-01, 1991-02-02, 1991-03-03, 1991-04-04, 1991-05-05, 1991-06-06, ...
# RWA   1990-01-01 - 1990-01-12, 1991-01-01 - 1991-01-12, 1992-01-01 - 1992-01-12, 1993-01-01 - 1993-01-12, 1994-01-01 
```

## `overview_crosstab`
To generate a cross table that divides the data based on two conditions, for instance GDP and population size, ```overview_crosstab``` can be used. `threshold1` and `threshold2` thereby indicate the cut point for the two conditions (`cond1` and `cond2`), respectively. 

```{r, message=FALSE, warning=FALSE, eval=FALSE}
output_crosstab <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
```

The data frame output looks as follows:

```{r, message=FALSE, echo=FALSE, eval=FALSE}
output_crosstab
```
```
#   part1                                      part2
# 1 AGO (1990, 1992), FRA (1993), GBR (1997)   BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)
# 2 BEN (1997), RWA (1990)                     AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)
```

Note, if a data set is used that has multiple observations on the id-time unit, the function automatically aggregates the data set using the mean of condition 1 (`cond1`) and condition 2 (`cond2`). 

## `overview_latex`

> With overviewR v 0.0.11.999 we introduced `overview_latex` instead of `overview_print`

To generate an easily usable LaTeX output for the generated `overview_tab` and `overview_crosstab` objects, `overviewR` offers the function `overview_latex`. 
The following illustrate this using the `output_table` object from `overview_tab`.

```{r, eval=FALSE}
overview_latex(obj = output_table)
```
<details>
  <summary>LaTeX output</summary>
```{r, eval=FALSE, include=FALSE}
overview_latex(obj = output_table)
```
```
% Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
% Table created on 2020-06-21
\begin{table}[ht] 
 \centering 
 \caption{Time and scope of the sample} 
 \begin{tabular}{ll} 
 \hline 
Sample & Time frame \\ 
\hline 
 RWA & 1990 - 1995 \\ 
 AGO & 1990 - 1992 \\ 
 BEN & 1995 - 1999 \\ 
 GBR & 1991, 1993, 1995, 1997, 1999 \\ 
 FRA & 1993, 1996, 1999 \\ 
 \hline 
 \end{tabular} 
 \end{table}
```
</details>

<p align="center">
<img src='ex1.png' height="150"/>
</p>

The default already provides a title ("Time and scope of the sample") that can be modified in the argument `title`. The same holds for the column names ("Sample" and "Time frame" are set by default but can be modified as shown below). 

```{r, eval = FALSE, eval=FALSE}
overview_latex(
  obj = output_table,
  id = "Countries",
  time = "Years",
  title = "Cool new title for our awesome table"
)
```
<details>
  <summary>LaTeX output</summary>
```{r, eval=FALSE, include=FALSE}
overview_latex(
  obj = output_table,
  id = "Countries",
  time = "Years",
  title = "Cool new title for our awesome table"
)
```

```
% Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
% Table created on 2020-06-21
\begin{table}[ht] 
 \centering 
 \caption{Cool new title for our awesome table} 
 \begin{tabular}{ll} 
 \hline 
Countries & Years \\ 
\hline 
 RWA & 1990 - 1995 \\ 
 AGO & 1990 - 1992 \\ 
 BEN & 1995 - 1999 \\ 
 GBR & 1991, 1993, 1995, 1997, 1999 \\ 
 FRA & 1993, 1996, 1999 \\ 
 \hline 
 \end{tabular} 
 \end{table} 
```
</details>

<p align="center">
<img src='ex2.png' height="150"/>
</p>



The same function can also be used for outputs from the `overview_crosstab` function by using the argument `crosstab = TRUE`. There are also options to label the respective conditions (```cond1``` and ```cond2```). Note that this should correspond to the conditions (```cond1``` and ```cond2```) specified in the `overview_crosstab` function.

```{r, eval = FALSE}
overview_latex(
  obj = output_crosstab,
  title = "Cross table of the sample",
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
```
<details>
  <summary>LaTeX output</summary>
```{r, eval=FALSE, include=FALSE}
overview_latex(
  obj = output_crosstab,
  title = "Cross table of the sample",
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
```
```
% Overview table generated in R version 4.0.0 (2020-04-24) using overviewR 
% Table created on 2020-06-21
% Please add the following packages to your document preamble: 
% \usepackage{multirow} 
% \usepackage{tabularx} 
% \newcolumntype{b}{X} 
% \newcolumntype{s}{>{\hsize=.5\hsize}X} 
\begin{table}[ht] 
\caption{Cross table of the sample} 
 \begin{tabularx}{\textwidth}{ssbb} 
\hline & & \multicolumn{2}{c}{\textbf{GDP}} \\ 
 & & \textbf{Fulfilled} & \textbf{Not fulfilled} \\ 
 \hline \\ 
 \multirow{2}{*}{\textbf{Population}} & \textbf{Fulfilled} & 
 AGO (1990, 1992), FRA (1993), GBR (1997) & BEN (1996, 1999), FRA (1999), GBR (1993), RWA (1992, 1994)\\  
 \\ \hline \\ 
 & \textbf{Not fulfilled} &  BEN (1997), RWA (1990) & AGO (1991), BEN (1995, 1998), FRA (1996), GBR (1991, 1995, 1999), RWA (1991, 1993, 1995)\\  \hline \\ 
 \end{tabularx} 
 \end{table} 
```
</details>

<p align="center">
<img src='ex3.png' height="200"/>
</p>

`overview_latex` further allows more specifications such as the font size or a a label. 
```{r, eval = FALSE}
overview_latex(obj = output_table,
               fontsize = "scriptsize",
               label = "tab:overview")
```

With ```save_out = TRUE``` the function exports the output as a ```.tex``` file and stores it on the device.

```{r, eval = FALSE}
overview_latex(
  obj = output_table,
  save_out = TRUE,
  file_path = "SET-YOUR-PATH/output.tex"
)
```

## `overview_markdown`

`overview_markdown` mirrors the functionality of `overview_latex` but produces Markdown output — useful for R Markdown documents, GitHub READMEs, or any Markdown-based workflow.

```{r, eval=FALSE}
overview_markdown(obj = output_table)
```

```
## Time and scope of the sample
| Sample | Time frame |
|--------|------------|
| RWA | 1990 - 1995 |
| AGO | 1990 - 1992 |
| BEN | 1995 - 1999 |
| GBR | 1991, 1993, 1995, 1997, 1999 |
| FRA | 1993, 1996, 1999 |
```

The column headers can be customised with `id` and `time`, and the title with `title`.

```{r, eval=FALSE}
overview_markdown(
  obj = output_table,
  id = "Countries",
  time = "Years",
  title = "My custom title"
)
```

For cross-tab objects, set `crosstab = TRUE` and provide condition labels:

```{r, eval=FALSE}
overview_markdown(
  obj = output_crosstab,
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
```

Use `save_out = TRUE` together with `file_path` to write the table directly to a `.md` file:

```{r, eval=FALSE}
overview_markdown(
  obj = output_table,
  save_out = TRUE,
  file_path = "output/overview.md"
)
```

# Visual overview

## `overview_plot`

In addition to tables, `overviewR` also provides plots to illustrate the structure of your data. 
`overview_plot` illustrates the information that is generated in `overview_table` in a ggplot graphic. All scope objects (e.g., countries) are listed on the y-axis where horizontal lines indicate the coverage across the entire time frame of the data (x-axis). This helps to spot gaps in the data for specific scope objects and outlines at what time point they occur. 

```{r, out.width = '50%', fig.align='center'}
data(toydata)
overview_plot(dat = toydata, id = ccode, time = year)
```

The results are sorted alphabetically by default. The order can also be reversed by setting `asc` to `FALSE`.

```{r, out.width = '50%', fig.align='center'}
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  asc = FALSE
)
```

There is also an option to color the time lines conditionally. Here, we introduce a dummy variable that indicates whether the year was before 1995 or not. We use this dummy to color the time lines using the `color` argument.

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
library(overviewR) # Easily Extracting Information About Your Data
library(magrittr) # A Forward-Pipe Operator for R

# Code whether a year was before 1995
toydata <- toydata %>%
  dplyr::mutate(before = ifelse(year < 1995, 1, 0))

# Plot using the `color` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
)
```


Since `overview_plot` returns a ggplot object, you can apply any ggplot2 color scale directly by adding a layer. This works for any number of categories.

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
library(ggplot2)

# Explicit colors via scale_color_manual
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_manual(values = c("#E84646", "#4E84C4"))
```

```{r, eval = FALSE}
# RColorBrewer palette via scale_color_brewer
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  color = before
) +
  ggplot2::scale_color_brewer(palette = "Set1")
```

The development version also allows to change the dot size using the `dot_size` argument. The default is "2".

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
# Plot using the `dot_size` argument
overview_plot(
  dat = toydata,
  id = ccode,
  time = year,
  dot_size = 5
)
```

## `overview_crossplot`

To visualize the cross table, `overview_crossplot` does the job. It places each observation in one of four quadrants defined by `threshold1` (x-axis) and `threshold2` (y-axis).

**Basic plot** — points only, no coloring or labels:

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000
)
```

**With quadrant coloring** (`color = TRUE`) — each quadrant gets a distinct color, making it easy to see how observations cluster:

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE
)
```

**With labels** (`label = TRUE`) — adds id–time labels to each point using `ggrepel` to avoid overlaps:

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  label = TRUE
)
```

**With both coloring and labels** — the most informative variant:

```{r, out.width = '50%', fig.align='center', include = TRUE, results = TRUE, message = FALSE, warning=FALSE}
overview_crossplot(
  toydata,
  id = ccode,
  time = year,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  color = TRUE,
  label = TRUE
)
```


## `overview_heat`

`overview_heat` takes a closer look at the time and scope conditions by visualizing the data coverage for each time and scope combination in a ggplot heat map. This function is best explained using an example. Suppose you have a dataset with monthly data for different countries and want to know if data is available for each country in every month. `overview_heat` intuitively does this by plotting a heat map where each cell indicates the coverage for that specific combination of time and scope (e,g., country-year). As illustrated below, the darker the cell is, the more coverage it has. The plot also indicates the relative or absolute coverage of each cell. For instance, Angola ("AGO") in 1991 shows the coverage of 75%. This means that of all potential 12 months of coverage (12 months for one year), only 9 are covered.

For this purpose, we first artificially reduced the `toydata`.

```{r, include = TRUE}
toydata_red <- toydata[-sample(seq_len(nrow(toydata)), 64), ]
```

```{r, out.width = '50%', fig.align='center'}
overview_heat(toydata_red,
              ccode,
              year,
              perc = TRUE,
              exp_total = 12)
```


## `overview_na`

`overview_na` is a simple function that provides information about the content of all variables in your data, not only the time and scope conditions. It returns a horizontal ggplot bar plot that indicates the amount of missing data (NAs) for each variable (on the y-axis). You can choose whether to display the relative amount of NAs for each variable in percentage (the default) or the total number of NAs.

For this purpose, we first artificially reduced our `toydata`.

```{r, include=TRUE}
toydata_with_na <- toydata %>%
  dplyr::mutate(
    year = ifelse(year < 1992, NA, year),
    month = ifelse(month %in% c("Jan", "Jun", "Aug"), NA, month),
    gdp = ifelse(gdp < 20000, NA, gdp)
  )
```

```{r, out.width = '50%', fig.align='center'}
overview_na(toydata_with_na)
```

```{r, out.width = '50%', fig.align='center'}
overview_na(toydata_with_na, perc = FALSE)
```

### Row-wise NA overview

By default, `overview_na` summarises NAs *column-wise* (one bar per variable). Setting `row_wise = TRUE` switches to a *row-wise* perspective: each observation on the y-axis, NA count on the x-axis. This is useful to spot rows that are largely empty.

```{r, out.width = '50%', fig.align='center'}
overview_na(toydata_with_na, row_wise = TRUE)
```

```{r, out.width = '50%', fig.align='center'}
overview_na(toydata_with_na, row_wise = TRUE, perc = FALSE)
```

You can also append the row-wise NA count and percentage directly to your original data frame with `add = TRUE`. This returns a data frame rather than a plot.

```{r, eval=FALSE}
toydata_extended <- overview_na(toydata_with_na, row_wise = TRUE, add = TRUE)
head(toydata_extended)
```

## `overview_overlap`

This function allows to compare two data sets. We are currently working on an extended version that allows comparing >2 data sets. 
  
  At the current development stage, the function works as follows:
  
```{r, out.width = '50%', fig.align='center', eval = TRUE}
library(dplyr)

# Subset one data set for comparison
toydata2 <- toydata %>% dplyr::filter(year > 1992)

overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "bar" # This is the default
)
```

  
  Or a Venn diagram
```{r_venn, out.width = '50%', fig.align='center', eval = TRUE}
overview_overlap(
  dat1 = toydata,
  dat2 = toydata2,
  dat1_id = ccode,
  dat2_id = ccode,
  plot_type = "venn"
)
```


## Customizing plots: `ggplot2`

The plot functions are fully `ggplot2` based. While a theme is pre-defined, this can easily be overwritten.

A classical `ggplot2` theme alternative
```{r, out.width = '50%', fig.align='center'}
library(ggplot2) # Create Elegant Data Visualisations 
                 # Using the Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal()
```

# Compatibilities with other packages 

## Workflow: `tidyverse`

All functions are further easily accessible using a common `tidyverse` workflow. Here are just three examples -- the possibilities are endless.

Using a filter function
```{r, out.width = '50%', fig.align='center'}
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata_with_na %>%
  dplyr::filter(year > 1993) %>%
  overview_na()
```

Using mutate to generate meaningful country names
```{r, out.width = '50%', fig.align='center'}
library(countrycode) # Convert Country Names and Country Codes
library(dplyr) # A Grammar of Data Manipulation # A Grammar of Data Manipulation

toydata %>%
  # Transform the country code (ISO3 character code) into a country name using
  # the `countrycode` package
  dplyr::mutate(country =
                  countrycode::countrycode(ccode, "iso3c", "country.name")) %>%
  overview_plot(id = country, time = year)
```

Using different `overviewR` functions after each other to generate a workflow
```{r, eval = FALSE}
# Produces a printable LaTeX output
toydata %>%
  overview_tab(id = ccode, time = year) %>%
  overview_latex()
```

```
% Overview table generated in R version 4.0.2 (2020-06-22) using overviewR 
% Table created on 2020-12-30
\begin{table}[ht] 
 \centering 
 \caption{Time and scope of the sample} 
\label{tab:tab1} 

\begin{tabular}{ll} 
 \hline 
Sample & Time frame \\ 
\hline 
 AGO & 1990 - 1992 \\ 
 BEN & 1995 - 1999 \\ 
 FRA & 1993, 1996, 1999 \\ 
 GBR & 1991, 1993, 1995, 1997, 1999 \\ 
 RWA & 1990 - 1995 \\ 
 \hline 
 \end{tabular} 
 \end{table} 
```

## Presenting tables: `flextable`, `xtable`, and `kable`
The outputs of `overview_tab` and `overview_crosstab` are also compatible with other functions such as [`xtable`](https://CRAN.R-project.org/package=xtable), [`flextable`](https://CRAN.R-project.org/package=flextable), or [`kable`](https://yihui.org/rmarkdown-cookbook/kable.html) from [`knitr`](https://yihui.org/knitr/).

Two examples are shown below:

```{r, eval=FALSE}
library(flextable) # not installed on this machine
table_output <- qflextable(output_table)
table_output <-
  set_header_labels(table_output,
                    ccode = "Countries",
                    time_frame = "Time frame")
set_table_properties(table_output,
                     width = .4,
                     layout = "autofit")
```

```{r, echo=FALSE, include=FALSE}
output_table <-
  data.frame(
    ccode = c("RWA", "AGO", "BEN", "GBR", "FRA"),
    time_frame = c(
      "1990-1995",
      "1990-1992",
      "1995-1999",
      "1991, 1993, 1995, 1997, 1999",
      "1993, 1996, 1999"
    )
  )
```

```{r}
library(knitr) # A General-Purpose Package for Dynamic Report Generation in R
knitr::kable(output_table)
```


A classical `ggplot2` theme alternative
```{r, out.width = '50%', fig.align='center'}
library(ggplot2) # Create Elegant Data Visualisations Using the
# Grammar of Graphics

overview_na(toydata_with_na) +
  ggplot2::theme_minimal()
```


## Extensions

If you wish to compare two data sets using `overview_tab`, this is not (yet) implemented in `overviewR` but there is currently a workaround. 

```{r, eval=TRUE}
library(overviewR)
library(dplyr)
library(xtable)

# Load data
data(toydata)

# Restrict the data so that we have something to compare :-)
toydata_res <- toydata %>%
  dplyr::filter(year > 1992)

# Generate two overview_tab objects
dat1 <- overview_tab(toydata, id = ccode, time = year)
dat2 <- overview_tab(toydata_res, id = ccode, time = year)

# And now we use full_join to combine both
dat_full <- dat1 %>%
  dplyr::full_join(dat2, by = "ccode") %>%
  dplyr::rename(time_dat1 = time_frame.x,
                time_dat2 = time_frame.y)
```

Having a look at the output, we see that this is exactly what we wanted to have:
```{r, eval=FALSE}
head(dat_full)
```
```
#> # A tibble: 5 x 3
#> # Groups:   ccode [5]
#>   ccode time_dat1                    time_dat2             
#>   <chr> <chr>                        <chr>                 
#> 1 AGO   1990 - 1992                  <NA>                  
#> 2 BEN   1995 - 1999                  1995 - 1999           
#> 3 FRA   1993, 1996, 1999             1993, 1996, 1999      
#> 4 GBR   1991, 1993, 1995, 1997, 1999 1993, 1995, 1997, 1999
#> 5 RWA   1990 - 1995                  1993 - 1995
```

`overview_latex` cannot handle this object (yet), so we use `xtable` instead which gives us the LaTeX output.

```{r, eval=FALSE}
print(xtable(dat_full), include.rownames = FALSE)
```

```
% latex table generated in R 4.0.2 by xtable 1.8-4 package
% Tue Feb 16 18:20:51 2021
\begin{table}[ht]
\centering
\begin{tabular}{lll}
  \hline
ccode & time\_dat1 & time\_dat2 \\ 
  \hline
AGO & 1990 - 1992 &  \\ 
  BEN & 1995 - 1999 & 1995 - 1999 \\ 
  FRA & 1993, 1996, 1999 & 1993, 1996, 1999 \\ 
  GBR & 1991, 1993, 1995, 1997, 1999 & 1993, 1995, 1997, 1999 \\ 
  RWA & 1990 - 1995 & 1993 - 1995 \\ 
   \hline
\end{tabular}
\end{table}
```

</details>

<p align="center">
<img src='extension1.png' height="150"/>
</p>

---
title: "Getting started"
description: >
  Learn what overviewR is about
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Getting started}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---


## <i class="far fa-lightbulb"></i> What is overviewR?

overviewR is a small yet powerful package that helps you to **get an overview** – hence, the name – **of your data** with particular emphasis on the **extent that your distinct units of observation are covered for the entire time frame** of your data set.


## <i class="far fa-download"></i> How can you install it?

A stable version of `overviewR` can be directly accessed on CRAN:
```{r, eval=FALSE}
install.packages("overviewR", force = TRUE)
```

To install the latest development version of `overviewR` directly from [GitHub](https://github.com/cosimameyer/overviewR) use: 

```{r, message=FALSE, warning=FALSE, results = "hide", eval=FALSE}
library(devtools)
devtools::install_github("cosimameyer/overviewR")
```


## </a><i class="fas fa-table"></i> Why did we build it?

If you have a (large) data set that has many different observations over a long period, it becomes increasingly **difficult to identify for each unique observation its exact coverage in the data**. In particular, if some observations are not included for the entire time span of the data – either because they entered later, dropped out earlier or have gaps in between – it can become difficult to spot potential problems in your data’s time and scope.

overviewR allows you to **quickly get a glimpse of your data and the distribution of your observations over time**. With its ability to **produce both data.frame objects and LaTeX/.tex outputs**, it can be used by **practitioners and academics alike**.

## <i class="fas fa-code"></i> How can it be used?

overviewR can be used by everyone who works with data that have **time-and-scope characteristics**. That is, all data that contains different units of observation over a specific period will benefit from overviewR. To get a quick overview of **which units** – think of countries, companies, test persons, etc. – **are present or missing during a given time span** – think of years, months, days, minutes, etc. – overviewR provides an **easy and intuitive insight** into the set-up of your data.

Consider a data set that covers countries over the past 50 years. **Not all countries existed throughout the entire period** – some dissolved, others were newly founded and yet for others, data might not be available for the entire period. Before starting any analysis, it is helpful to get an overview not only of which countries are included and what the entire time span is but also to **see which countries are present at which points in time**. In other words, are there missing data for certain countries at different points in time?

To get a quick and intuitive overview of your data, overviewR provides currently the following basic functions:

- **overview_tab** generates a basic table that lists all unique units of observation (e.g., countries) and aggregates the time frame at which each unit is present in the data set. This means it also takes into account gaps in the data set, e.g., when there is – for whatever reason – no data available for a country for a few years within the time frame
- **overview_crosstab** generates a similar table but allows you to separate the overview table using two conditions. For instance, you want to know not only at what time points countries are present in your data but also when these countries can be considered to have high or low GDP and can be categorized as having a small or large population size. For this, overview_crosstab is used.
- **overview_latex** takes a table – either generated by overview_tab or overview_crosstab and turns it into a LaTeX output. It even allows you to save the LaTeX output in a ready-to-use .tex file.
- **overview_plot** visualizes the time and scope conditions of your data in a ggplot plot. For each scope object in your data (e.g., countries) on the y-axis, it plots the time coverage (x-axis) as a horizontal line for all time points in your data. This helps to spot gaps in your data for specific scope objects or simply creates a graphical display of your time and scope conditions and can be a good companion for presentation slides or appendices.
overview_crossplot is an alternative to visualize a cross table (a way to present results from overview_crosstab)
- **overview_heat** visualizes the coverage of each time and scope combination of your dataset in a heat map style ggplot. Each cell in the heat map is colored based on the coverage of a scope object at a given time point. Additionally, it displays either the total number of cases covered or a relative percentage as plain text. This helps to spot missing information even more nuanced. For instance, in a monthly data set with countries as the scope object, it illustrates the percentage of covered months in the data for each country-year combination.
- **overview_na** graphically illustrates the total number of NAs across all variables in your data set as a horizontal bar plot. Similar to the other plot objects, overview_na returns a ggplot object and can be modified and adjusted accordingly.
- **overview_overlap**  provides an overview of the overlap of two data sets

## Overview of functional add-ons
|                       | Works with `data.frame` objects | Works with `data.table` | Can take multiple time arguments (year, month, day) |
|-----------------------|---------------------------------|-------------------------|-----------------------------------------------------|
| `overview_tab`        | yes                               | yes                       | yes                                                   |
| `overview_na`         | yes                               | yes                       |                                                     |
| `overview_plot`       | yes                               |                         |                                                     |
| `overview_crossplot`  | yes                               |                         |                                                     |
| `overview_crosstab`   | yes                               |                         |                                                     |
| `overview_heat`       | yes                               |                         |                                                     |
| `overview_overlap`    | yes                               |                         |                                                     |


There is also a [CheatSheet](https://github.com/rstudio/cheatsheets/blob/main/overviewR.pdf) available here that showcases the functions of overviewR.


## <i class="fas fa-people-carry"></i> Get involved!

Have you used overviewR in your project? **Let us know!** You can either e-mail us or use our pull-request template and populate/fill the following with your information:

```
**PROJECT TITLE**:
--SHORT DESCRIPTION HOW YOU USED OVERVIEWR--
[*LINK TO YOUR WEBSITE*](https://LINK-TO-YOUR-WEBSITE)
```

We will feature your project below!

## <i class="fas fa-medal"></i> Projects using overviewR

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_heat.R
\name{overview_heat}
\alias{overview_heat}
\title{overview_heat}
\usage{
overview_heat(
  dat,
  id,
  time,
  perc = FALSE,
  exp_total = NULL,
  xaxis = "Time frame",
  yaxis = "Sample",
  col_low = "#dceaf2",
  col_high = "#2A5773",
  label = TRUE
)
}
\arguments{
\item{dat}{The data set}

\item{id}{The scope (e.g., country codes or individual IDs). The axis is
ordered in ascending order by default.}

\item{time}{The time (e.g., time periods given by years, months, ...)}

\item{perc}{If FALSE (default) plot returns the total number of observations
per time-scope-unit. If TRUE, it returns the number of observations per
time-scope-unit in percentage}

\item{exp_total}{Expected total number of observations (i.e. maximum)
for time unit.}

\item{xaxis}{Label of your x axis ("Time frame" is default)}

\item{yaxis}{Label of your y axis ("Sample" is default)}

\item{col_low}{Hex color code for the lowest value (default is "#dceaf2")}

\item{col_high}{Hex color code for the lowest value (default is "#2A5773")}

\item{label}{If TRUE (default), the total number of observations/percentages
of observations are displayed. If FALSE, it returns no labels.}
}
\value{
A ggplot figure that presents sample coverage visually
}
\description{
This function plots a heat map to visualize the
    coverage of the time-scope-units of the data. Options include total
    number of cases per time-scope-unit or relative number in percentage.
}
\examples{
data(toydata)
overview_heat(toydata, ccode, year, perc = TRUE, exp_total = 12)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_latex.R
\name{overview_latex}
\alias{overview_latex}
\title{overview_latex}
\usage{
overview_latex(
  obj,
  title = "Time and scope of the sample",
  id = "Sample",
  time = "Time frame",
  crosstab = FALSE,
  cond1 = "Condition 1",
  cond2 = "Condition 2",
  save_out = FALSE,
  file_path,
  label = "tab:tab1",
  fontsize,
  file,
  path
)
}
\arguments{
\item{obj}{Overview object produced by overview_tab or overview_crosstab}

\item{title}{Caption of the table (default is "Time and scope of the sample")}

\item{id}{The name of the left column (default is "Sample"), will be ignored
if crosstab is TRUE}

\item{time}{The name of the right column (default is ("Time frame")), will
be ignored if \code{crosstab} is TRUE}

\item{crosstab}{Logical argument, if TRUE produces a \code{crosstab} output,
default is FALSE}

\item{cond1}{Description for the first condition (character), will be
ignored if \code{crosstab} is FALSE. This should correspond to the input
for \code{cond1} in \code{overview_crosstab}}

\item{cond2}{Description for the second condition (character), will be
ignored if \code{crosstab} is FALSE. This should correspond to the input
for \code{cond2} in \code{overview_crosstab}}

\item{save_out}{Optional argument, exports the output table as a .tex
file, default is FALSE}

\item{file_path}{Specifies the path and file name (.tex) where you store your output}

\item{label}{Specifies the label (default is "tab:tab1")}

\item{fontsize}{Specifies the font size (all 'LaTeX' font sizes such as
"scriptsize" or "small" work)}

\item{file}{This argument is deprecated. Please use "file_path" instead and add the full path.}

\item{path}{This argument is deprecated. Please use "file_path" instead and add the full path.}
}
\value{
A 'LaTeX' output that can either be copy-pasted in a text document or
    exported directed as a .tex file
}
\description{
Produces a 'LaTeX' output for output obtained via
   \code{overview_tab} and \code{overview_crosstab}
}
\examples{
data(toydata)

overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
overview_latex(
  obj = overview_object,
  title = "Some nice title",
  crosstab = FALSE
)

#' overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
overview_latex(
  obj = overview_object,
  title = "Some nice title",
  file_path = "some/path_to/your_output_file.tex"
)

overview_ct_object <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
overview_latex(
  obj = overview_ct_object,
  title = "Some nice title for a cross tab",
  crosstab = TRUE,
  cond1 = "Name of first condition",
  cond2 = "Name of second condition"
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_crossplot.R
\name{overview_crossplot}
\alias{overview_crossplot}
\title{overview_crossplot}
\usage{
overview_crossplot(
  dat,
  id,
  time,
  cond1,
  cond2,
  threshold1,
  threshold2,
  xaxis = "Condition 1",
  yaxis = "Condition 2",
  label = FALSE,
  color = FALSE,
  dot_size = 2,
  fontsize = 2.5
)
}
\arguments{
\item{dat}{Your data set}

\item{id}{Your scope (e.g., country codes or individual IDs). If the id
variable contains NAs, they will not be included in the plot.}

\item{time}{Your time (e.g., time periods given by years, months, ...)}

\item{cond1}{Variable that describes the first condition}

\item{cond2}{Variable that describes the second condition}

\item{threshold1}{A threshold for \code{cond1}}

\item{threshold2}{A threshold for \code{cond2}}

\item{xaxis}{Label of the x axis ("Condition 1" is default)}

\item{yaxis}{Label of the y axis ("Condition 2" is default)}

\item{label}{Label of the observations. Overlapping labels are
avoided by using 'ggrepel'}

\item{color}{Color of the different observation groups}

\item{dot_size}{Option argument that defines the dot size (default is 2)}

\item{fontsize}{If label is TRUE, the fontsize arguments allows to define the text of the labels (the default is 2.5)}
}
\value{
A ggplot figure that presents the sample information visually
    in a cross table
}
\description{
This function plots a ggplot to visualize a cross table plot.
}
\examples{
data(toydata)
overview_crossplot(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_add_na_output.R
\name{overview_add_na_output}
\alias{overview_add_na_output}
\title{overview_add_na_output}
\usage{
overview_add_na_output(dat_result = NULL, dat = NULL)
}
\arguments{
\item{dat_result}{Data.frame from `overview_na`}

\item{dat}{Data frame}
}
\value{
The function returns a data set that has the information
    on the row-wise NA share
}
\description{
Function used in `overview_na` to generate a new data frame with
    na_count and percentage share of NAs for each row
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helper.R
\name{find_int_runs}
\alias{find_int_runs}
\title{find_int_runs}
\usage{
find_int_runs(run = NULL)
}
\arguments{
\item{run}{Variable (integer) that should be checked for consecutive values}
}
\value{
The function returns a data set
}
\description{
Function used in `overview_tab` to find running integers
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_share_row_wise.R
\name{calculate_share_row_wise}
\alias{calculate_share_row_wise}
\title{calculate_share_row_wise}
\usage{
calculate_share_row_wise(dat = NULL)
}
\arguments{
\item{dat}{Data frame}
}
\value{
The function returns a data set that has the information
    on the row-wise NA share
}
\description{
Function used in `overview_na` to calculate the share of NA row-wise
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_markdown.R
\name{overview_markdown}
\alias{overview_markdown}
\title{overview_markdown}
\usage{
overview_markdown(
  obj,
  title = "Time and scope of the sample",
  id = "Sample",
  time = "Time frame",
  crosstab = FALSE,
  cond1 = "Condition 1",
  cond2 = "Condition 2",
  save_out = FALSE,
  file_path = ""
)
}
\arguments{
\item{obj}{Overview object produced by \code{overview_tab} or
\code{overview_crosstab}}

\item{title}{Optional title printed as a Markdown heading above the table.
Defaults to \code{"Time and scope of the sample"}.}

\item{id}{The header of the left column (default is \code{"Sample"}).
Ignored when \code{crosstab = TRUE}.}

\item{time}{The header of the right column (default is \code{"Time frame"}).
Ignored when \code{crosstab = TRUE}.}

\item{crosstab}{Logical. If \code{TRUE} produces a cross-table output.
Default is \code{FALSE}.}

\item{cond1}{Label for the first condition. Ignored when
\code{crosstab = FALSE}.}

\item{cond2}{Label for the second condition. Ignored when
\code{crosstab = FALSE}.}

\item{save_out}{Logical. If \code{TRUE} writes the output to a file.
Default is \code{FALSE}.}

\item{file_path}{Path (including file name with \code{.md} extension) where
the output is stored when \code{save_out = TRUE}.}
}
\value{
Invisibly returns a character string with the Markdown table. The
    table is also printed to the console (unless \code{save_out = TRUE}).
}
\description{
Produces a Markdown table output for objects obtained via
   \code{overview_tab} and \code{overview_crosstab}
}
\examples{
data(toydata)

overview_object <- overview_tab(dat = toydata, id = ccode, time = year)
overview_markdown(obj = overview_object)

overview_ct_object <- overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
overview_markdown(
  obj = overview_ct_object,
  crosstab = TRUE,
  cond1 = "GDP",
  cond2 = "Population"
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/private_overview_heat.R
\name{.overview_heat}
\alias{.overview_heat}
\title{.overview_tab}
\usage{
.overview_heat(
  dat = NULL,
  id = NULL,
  time = NULL,
  label = FALSE,
  perc = FALSE,
  col_low = NULL,
  col_high = NULL,
  xaxis = NULL,
  yaxis = NULL,
  theme_plot = NULL,
  exp_total = NULL,
  col_names = NULL
)
}
\arguments{
\item{dat}{The data set}

\item{id}{The scope (e.g., country codes or individual IDs). The axis is
ordered in ascending order by default.}

\item{time}{The time (e.g., time periods given by years, months, ...)}

\item{label}{If TRUE (default), the total number of observations/percentages
of observations are displayed. If FALSE, it returns no labels.}

\item{perc}{If FALSE (default) plot returns the total number of observations
per time-scope-unit. If TRUE, it returns the number of observations per
time-scope-unit in percentage}

\item{col_low}{Hex color code for the lowest value (default is "#dceaf2")}

\item{col_high}{Hex color code for the lowest value (default is "#2A5773")}

\item{xaxis}{Label of your x axis ("Time frame" is default)}

\item{yaxis}{Label of your y axis ("Sample" is default)}

\item{theme_plot}{Previously generated theme}

\item{exp_total}{Expected total number of observations (i.e. maximum)
for time unit.}

\item{col_names}{The column names (containing id and time)}
}
\value{
A ggplot
}
\description{
Internal function that calculates the `overview_tab` for data.table objects
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_overlap.R
\name{overview_overlap}
\alias{overview_overlap}
\title{overview_overlap}
\usage{
overview_overlap(
  dat1,
  dat2,
  dat1_id,
  dat2_id,
  dat1_name = "Data set 1",
  dat2_name = "Data set 2",
  plot_type = "bar",
  proportional = FALSE
)
}
\arguments{
\item{dat1}{A first data set object}

\item{dat2}{A second data set object}

\item{dat1_id}{Scope (e.g., country codes or individual IDs) of dat1.
It is important that both ID variables are exactly the same to generate
the perfect match.}

\item{dat2_id}{Scope (e.g., country codes or individual IDs) of dat2.
It is important that both ID variables are exactly the same to generate
the perfect match.}

\item{dat1_name}{Name of dat1 ("Data set 1" is the default)}

\item{dat2_name}{Name of dat2 ("Data set 2" is the default)}

\item{plot_type}{Type of plot ("bar" and "venn" are the two options) "venn"
relies on the ggvenn function}

\item{proportional}{Logical. If \code{TRUE} and \code{plot_type = "venn"},
draws a proportional Euler diagram using the \pkg{eulerr} package
(must be installed separately). The returned object is an
\code{eulergram} (base-R graphics), not a ggplot2 object.
Default is \code{FALSE}.}
}
\value{
A ggplot2 object (bar chart or standard Venn diagram), or an
    \code{eulergram} object when \code{proportional = TRUE}.
}
\description{
Provides an overview of the overlap of two data sets.
    Cautionary note: This function is currently only preliminary workable
    and can only capture 2 data sets. We are working on an extension that
    allows to compare multiple data sets.
}
\examples{
\dontrun{
data(toydata)
toydata2 <- toydata[which(toydata$year > 1992), ]
overview_overlap(
  dat1 = toydata, dat2 = toydata2, dat1_id = ccode,
  dat2_id = ccode
)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_tab_df.R
\name{overview_tab_df}
\alias{overview_tab_df}
\title{overview_tab_df}
\usage{
overview_tab_df(dat2 = NULL, dat = NULL, id = NULL, time = NULL)
}
\arguments{
\item{dat2}{Your data set}

\item{dat}{Your data set}

\item{id}{Scope (e.g., country codes or individual IDs)}

\item{time}{Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).}
}
\value{
A data.frame
}
\description{
Internal function that calculates the `overview_tab` for data.frame objects
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_na.R
\name{overview_na}
\alias{overview_na}
\title{overview_na}
\usage{
overview_na(
  dat,
  yaxis = "Variables",
  perc = TRUE,
  row_wise = FALSE,
  add = FALSE
)
}
\arguments{
\item{dat}{Your data set}

\item{yaxis}{Label of your y axis ("Variables" is default)}

\item{perc}{If TRUE (default) plot returns the number of NAs in percentage}

\item{row_wise}{If TRUE (FALSE is default) plot return the number of NAs
per row}

\item{add}{If TRUE (FALSE is default) it generates a new data frame with
na_count and percentage share of NAs for each row}
}
\value{
Depending on the selection, the function returns a ggplot figure that
    presents the distribution of NAs in the data set or adds the information
    on the row-wise NA share
}
\description{
This function plots a ggplot to visualize the distribution of
    NAs across all variables in the data set.
}
\examples{
data(toydata)
overview_na(toydata, perc = FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_tab.R
\name{overview_tab}
\alias{overview_tab}
\title{overview_tab}
\usage{
overview_tab(
  dat,
  id,
  time = list(year = NULL, month = NULL, day = NULL),
  complex_date = FALSE
)
}
\arguments{
\item{dat}{A data frame or data table object}

\item{id}{Scope (e.g., country codes or individual IDs)}

\item{time}{Time (e.g., time periods given by years, months, ...). There are three options to add a date variable: 1) Time can be a character vector containing **one** time variable, 2) a time variable following the YYYY-MM-DD format, or 3) or a list containing multiple time variables (`time = list(year = NULL, month = NULL, day = NULL)`).}

\item{complex_date}{Boolean argument identifying if there is a more complex (list-wise) date_time parameter (FALSE is the default)}
}
\value{
A data frame object that contains a summary of a sample that
    can later be converted to a 'LaTeX' output using \code{overview_latex}
}
\description{
Provides an overview table for the time and scope conditions of
    a data set. If a data.table object is provided, the function uses
    data.table's syntax to perform the evaluation
}
\examples{
# With version 1 (and also 2):

data(toydata)
output_table <- overview_tab(dat = toydata, id = ccode, time = year)

# With version 3:
overview_tab(dat = toydata, id = ccode, time = list(
  year = toydata$year,
  month = toydata$month, day = toydata$day
), complex_date = TRUE)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_plot_absolute.R
\name{overview_plot_absolute}
\alias{overview_plot_absolute}
\title{overview_plot_absolute}
\usage{
overview_plot_absolute(
  dat_result = NULL,
  theme_plot = NULL,
  yaxis = NULL,
  xaxis = NULL
)
}
\arguments{
\item{dat_result}{Data frame}

\item{theme_plot}{Theme for the plot (pre-defined)}

\item{yaxis}{Name for yaxis}

\item{xaxis}{Name for xaxix}
}
\value{
The function returns a ggplot
}
\description{
Function used in `overview_na` to plot the absolute share of NA values
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme_heat_plot.R
\name{theme_heat_plot}
\alias{theme_heat_plot}
\title{theme_heat_plot}
\usage{
theme_heat_plot()
}
\value{
A theme for the `overview_heat` plot
}
\description{
Defines the theme for the `overview_heat` plot function
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_plot.R
\name{overview_plot}
\alias{overview_plot}
\title{overview_plot}
\usage{
overview_plot(
  dat,
  id,
  time,
  xaxis = "Time frame",
  yaxis = "Sample",
  asc = TRUE,
  color,
  dot_size = 2
)
}
\arguments{
\item{dat}{Your data set}

\item{id}{Your scope (e.g., country codes or individual IDs). If the id
variable contains NAs, they will not be included in the plot.}

\item{time}{Your time (e.g., time periods given by years, months, ...)}

\item{xaxis}{Label of the x axis ("Time frame" is default)}

\item{yaxis}{Label of the y axis ("Sample" is default)}

\item{asc}{Sorting the y axis in ascending order ("TRUE" is default)}

\item{color}{Optional argument. Either a column variable (for conditional
coloring) or a color string (e.g., \code{"steelblue"}) to paint all
lines/points a fixed color. When \code{color} is a column variable the
returned ggplot object can be extended with
\code{+ ggplot2::scale_color_manual()} or
\code{+ ggplot2::scale_color_brewer()} to apply custom palettes.}

\item{dot_size}{Option argument that defines the dot size (default is 2)}
}
\value{
A ggplot figure that presents the sample information visually
}
\description{
This function plots a ggplot to visualize the distribution of
    scope objects across the time frame.
}
\examples{
data(toydata)
overview_plot(dat = toydata, id = ccode, time = year)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/toydata.R
\docType{data}
\name{toydata}
\alias{toydata}
\title{Cross-sectional data for countries}
\format{
An object of class \code{"data.frame"}
\describe{
 \item{ccode}{ISO3 country code (as character) for the countries in the
     sample (Angola, Benin, France, Rwanda, and UK)}
 \item{year}{A value between 1990 and 1999}
 \item{month}{An abbreviation (MMM) for month (character)}
 \item{gpd}{A fake value for GDP (randomly generated)}
 \item{population}{A fake value for population (randomly generated)}
}
}
\usage{
data(toydata)
}
\description{
Small, artificially generated toy data set that comes in a cross-sectional
format where the unit of analysis is either country-year or
country-year-month. It provides artificial information for five countries
(Angola, Benin, France, Rwanda, and the UK) for a time span from 1990 to
1999 to illustrate the use of the package.
}
\examples{

data(toydata)
head(toydata)
}
\references{
This data set was artificially created for the overviewR package.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/overview_crosstab.R
\name{overview_crosstab}
\alias{overview_crosstab}
\title{overview_crosstab}
\usage{
overview_crosstab(dat, cond1, cond2, threshold1, threshold2, id, time)
}
\arguments{
\item{dat}{A data set object}

\item{cond1}{Variable that describes the first condition}

\item{cond2}{Variable that describes the second condition}

\item{threshold1}{A threshold for \code{cond1}}

\item{threshold2}{A threshold for \code{cond2}}

\item{id}{Scope (e.g., country codes or individual IDs)}

\item{time}{Time (e.g., time periods given by years, months, ...)}
}
\value{
A data frame object that contains a summary of the data set that can
      later be converted to a 'LaTeX' output using \code{overview_latex}
}
\description{
Sorts a data set conditionally in a cross table.
    This can be helpful to get a sense of the time and scope
    conditions of a data set. Note, if used with a data set that has multiple
    observations on the id-time unit, the function automatically aggregates
    this information using the mean.
}
\examples{
data(toydata)
overview_crosstab(
  dat = toydata,
  cond1 = gdp,
  cond2 = population,
  threshold1 = 25000,
  threshold2 = 27000,
  id = ccode,
  time = year
)
}
